/*

Replication files 

Leopold, T., & Skopek, J. (2015). The Demography of Grandparenthood: An International Profile. Social Forces, 94(2), 801–832. https://doi.org/10.1093/sf/sov066

Data Preparation for German Ageing Survey (DEAS).
Adjusted from previous paper "Delay of Grandparenthood" (Leopold & Skopek 2014)

*/



tempfile population_fractions kinder einzelenkel basisenkel enkel biokindermitenkel

/**
 Population based age distribution (valid date 31.12.2008; destatis) 
 for the cohorts under study 
**/
clear
	import excel using "${DEAS}/Bevölkerungsstruktur_Alter_Geschlecht_BL_2008/prepared.xlsx", firstrow
	reshape long M W T, i(age) j(land)

	destring age, replace
	lab def land 1 "BaWü" 2 "Bay" 3 "Berlin" 4 "Brand" 5 "Bremen" 6 "Hamb" 7 "Hessen" 8 "Meck-Pom" 9 "Nieders" ///
				 10 "NRW" 11 "RPF" 12 "Saarl" 13 "Sachsen" 14 "Sachsen-Anhalt" 15 "Schlesw-Hols" 16 "Thür", modify
	lab val land land

	keep if inrange(age,40,85)

	recode land (3 4 8 13 14 16 = 1) (else = 2), gen(part) // note Berlin assigned to east
	lab def part 1 "east" 2 "west" 


	collapse (sum) M W T, by(part age)
	assert M + W == T

	gen birth = 2008 - age

	recode birth (1929/1938=1 "1929-1938") ///
				 (1939/1948=2 "1939-1948") ///
				 (1949/1958=3 "1949-1958") ///
				 , gen(cohort)
	keep if inrange(cohort,1,3)

	tabstat age, by(cohort) stats(min max)

	set dp comma
	* EAST Cohort specific age structure of women
	tab age [fweight=W] if cohort==1 & part==1
	tab age [fweight=W] if cohort==2 & part==1
	tab age [fweight=W] if cohort==3 & part==1
	* EAST Cohort specific age structure of men 
	tab age [fweight=M] if cohort==1 & part==1
	tab age [fweight=M] if cohort==2 & part==1
	tab age [fweight=M] if cohort==3 & part==1

	* WEST Cohort specific age structure of women
	tab age [fweight=W] if cohort==1 & part==2
	tab age [fweight=W] if cohort==2 & part==2
	tab age [fweight=W] if cohort==3 & part==2
	* WESTCohort specific age structure of men 
	tab age [fweight=M] if cohort==1 & part==2
	tab age [fweight=M] if cohort==2 & part==2
	tab age [fweight=M] if cohort==3 & part==2
	set dp period

	* constract a data set for generating post-stratification weights
	* weights for age by part, cohort, sex
	drop birth
	rename M N1
	rename W N2
	reshape long N, i(part cohort age) j(sex)
	drop T 

	order part cohort sex age N
	sort part cohort sex age N

	isid part cohort sex age
	bys part cohort sex: egen sum = total(N)
	gen fraction = N/sum

	drop sum

	rename part part2008

	save `population_fractions', replace




* Original daten laden
use "${DEAS}/SUF_DEAS2008_v2.dta", clear

fre stich

* Einschränkung auf Basisstichprobe B2008
keep if stich==3

* Setze nicht-anonymisierte Geburtsdaten ein
preserve 
	use "${DEAS}/SUF_DEAS2008_Geburtsjahr", clear
	renvars x3041-x316d28j, pref(EXACT_)
	tempfile exact
	save `exact'
restore

merge 1:1 fallnum stich using `exact', nogen


* Geburtsdaten Kind 1-4
foreach var of varlist x3041 x3042 x3043 x3044 {
	order EXACT_`var', before(`var') 
	rename `var'  __`var' 
	rename EXACT_`var' `var'
}
* Geburtsdaten Kind 5-8
foreach num of numlist 5/8 {
	rename EXACT_x304`num' x304`num'
	order x304`num', before(x304`num'kat)
	drop x304`num'kat
}



* Einzelenkel (nicht kat-Variablen)
foreach var of varlist x316d1? x316d2?? {
	order EXACT_`var', before(`var') 
	rename `var'  __`var' 
	rename EXACT_`var' `var'
}


* Einzelenkel, Basisenkel 
* d x316d1? x316d1?kat x316d2?*
foreach var of varlist x316???kat x316????kat {
	local name: subinstr local var "kat" ""
	di "`name'"
	if "`name'" != "`var'" {
		gen `name' = EXACT_`name'
		order `name', before(`var')
		local label: variable label `var'
		local label: subinstr local label ", kategorisiert" ""
		lab var `name' "`label'"
		drop `var'
	} 
	drop EXACT_`name'
}

* Rest
order EXACT_x316d21k-EXACT_x316d21o, after(x316g21j)
renvars EXACT_x316d21k-EXACT_x316d21o, subst("EXACT_" "")
order __*, last

* (auskommentierung für prüfungen)
drop __*


************************************************
* Vorbereitung (Kinder, Enkel) >>>>>>
* (start)

* Kind & Enkelkinddaten aufbereiten
* Vorgehen: 
* Es werden nur Daten der ersten 4 Kinder aufbereitet, da ab dem 5. Kind wichtige Variabeln
* wie Geburtsjahr stark vergröbert wurden (Anonymisierungsprozedur bei DEAS). 
* Dies ist aber nur bedingt problematisch, da im Interview 
* vom ältesten Kind (erstgeborenen) ausgehend gefragt wird.

* Update: Geburtsdaten werden für alle Kinder berücksichtigt. Auszüge nur bis 
* zu dem 4. Kind.

* 
preserve 
	* Behalte nur variablen von 1-4 Kind
	* Nein nehme alle
	keep fallnum x300 x3011-x316j
	drop x316j
	keep fallnum x300 x301? x302? x303? x303a? x303b? x304? ///
				 x304a? x305? x306? x307? x308? x309? x311? /// 
				 x311a? x312? x313? x314? x315?kat x316? x316a?

	foreach stub in x301@ x302@ x303@ x303a@ x303b@ x304@ x304a@ x305@ x306@ x307@ x308@ x309@ x311@ x311a@ x312@ x313@ x314@ x315@kat x316@ x316a@ {
		local name: subinstr local stub "@" "", all
		local var: subinstr local stub "@" "1", all
		local lab: variable label `var'  
		local lab`name' "`lab'"
		local lab`name': subinstr local lab`name' "1." "", all
		local val: value label `var'
		local val`name' "`val'"
	}

	reshape long x301@ x302@ x303@ x303a@ x303b@ x304@ x304a@ x305@ x306@ x307@ x308@ x309@ x311@ x311a@ x312@ x313@ x314@ x315@kat x316@ x316a@, i(fallnum) j(kind)

	foreach var of varlist x301-x313 {
		lab var `var' "`lab`var''"
		lab val `var' `val`var''
	}

	// lösche überfilterte Variablen
	drop if x301==-1

	mvdecode x303 x303a x303b, mv(-1=.a \ 7/9=.a)

	* Marker für biologische Kinder
	gen bio = .
	replace bio = 1 if inlist(x303,1,2)
	replace bio = 1 if inlist(x303a,2)
	replace bio = 1 if inlist(x303b,2)


	* Geburtsdaten
	mvdecode x304, mv(9997/9998=.a)

	save `kinder', replace
restore

* EINZELENKEL (-> für diejenigen berichteten Kinder, die nur 1 Kind haben)
preserve

keep fallnum x316b1-x316j  
keep fallnum x316* 
drop x316j 

* Einzelenkel
keep fallnum x316b? x316c1? x316d1* x316d1? x316e1? x316f1? x316g1? 

* labels
foreach stub in x316b@ x316c1@ x316d1@ x316e1@ x316f1@ x316g1@ {
	local name: subinstr local stub "@" "", all
	local var: subinstr local stub "@" "1", all
	local lab: variable label `var'  
	local lab`name' "`lab'"
	local lab`name': subinstr local lab`name' "1." "", all
	local val: value label `var'
	local val`name' "`val'"
}


reshape long x316b@ x316c1@ x316d1@ x316e1@ x316f1@ x316g1@, i(fallnum) j(kind)

order fallnum kind x316b x316c1 x316d1 x316e1 x316f1 x316g1 

foreach var of varlist x316b-x316g1 {
	lab var `var' "`lab`var''"
	lab val `var' `val`var''
}
// überfilterungen löschen
drop if x316b==-1

// Fehlwerte
mvdecode x316c1, mv(8=.a)
mvdecode x316d1, mv(9997/9999=.a)

/*
datencheck: 
sort fallnum kind
li fallnum kind x316b x316c1 x316d1, sepby(fallnum)
*/

gen einzelenk = 1
save `einzelenkel', replace

restore


* Basisenkel (für Kinder, die mehr als 1 Kind haben)
preserve

keep fallnum x316b2* x316c2* x316d2* x316e2* x316g2* 

/*
// ab 3. Basisenkel ist Geburtsdatum vergröbert
// Workaround: schätze geburtsjahr anhand der klassenmitte
foreach var of varlist x316d2??kat {
	local varname: subinstr local var "kat" "", all
	recode `var' (1=1964) (2=1974) (3=1984) (4=1994) (5=2004), gen(`varname')
	order `varname', before(`var')
	drop `var'
}
*/

snapshot save, label("basisenkel")
foreach num of numlist 1/8 {
di `num'
tempfile basisenkel`num' 


local vars x316b2`num'? x316c2`num'? x316d2`num'? x316e2`num'?  x316g2`num'?
local stubs x316b2`num'@ x316c2`num'@ x316d2`num'@ x316e2`num'@  x316g2`num'@
if `num' > 4 {
	local vars x316b2`num'? x316c2`num'? x316d2`num'? 
	local stubs x316b2`num'@ x316c2`num'@ x316d2`num'@
}  
keep fallnum `vars' 
order fallnum `vars' 

foreach stub in `stubs' {
	local name: subinstr local stub "@" "", all
	local var: subinstr local stub "@" "a", all
	local lab: variable label `var'  
	local lab`name' "`lab'"
	local lab`name': subinstr local lab`name' "1." "", all
	local val: value label `var'
	local val`name' "`val'"
}

reshape long `stubs', i(fallnum) j(enkel) string

foreach var of varlist x316*  {
	lab var `var' "`lab`var''"
	lab val `var' `val`var''
	* variablen umbenennen (letztes Zeichen entfernen)
	renvars `var', postdrop(1)
}

drop enkel 
clonevar enkel = x316b2
drop if enkel == -1 | enkel == .
drop x316b2
gen kind = `num'
gen basisenkel = 1
order fallnum kind enkel

save `basisenkel`num'', replace
snapshot restore 1 
}



use `basisenkel1', clear
foreach num of numlist 2/8 {
	append using `basisenkel`num''
}

* missing values
mvdecode x316d2, mv(9997/9999=.a)
mvdecode x316c2, mv(7/8=.a)

save `basisenkel', replace
restore

* Zufallsenkel (1-4. Kind)
preserve 
keep fallnum zekcode? x316f3? x316g3? x316h3? x316i3? 

foreach stub in x316f3@ x316g3@ x316h3@ x316i3@ {
	local name: subinstr local stub "@" "", all
	local var: subinstr local stub "@" "1", all
	local lab: variable label `var'  
	local lab`name' "`lab'"
	local lab`name': subinstr local lab`name' "1." "", all
	local val: value label `var'
	local val`name' "`val'"
}

reshape long zekcode@ x316f3@ x316g3@ x316h3@ x316i3@, i(fallnum) j(kind)

foreach var of varlist x316f3 x316g3 x316h3 x316i3 {
	lab var `var' "`lab`var''"
	lab val `var' `val`var''
}
	
drop if zekcode==-1

rename zekcode enkel

gen basisenkel = 1
gen zufallsenkel = 1

tempfile zufallsenkel
save `zufallsenkel' 

use `basisenkel', clear

merge 1:1 fallnum kind enkel using `zufallsenkel', assert(master match)
drop _merge
replace zufallsenkel = 0 if zufallsenkel==.

save `basisenkel', replace
restore


* Variablen umbenennen und harmonisieren
preserve 
use `einzelenkel', clear

rename x316b enkel
rename x316c1 geschl 
rename x316d1 geburtsj
rename x316e1 leibl 
rename x316f1 inHH
rename x316g1 wohnentf
save `einzelenkel', replace


use `basisenkel', clear

capt drop x316b2
rename x316c2 geschl 
rename x316d2 geburtsj
rename x316e2 inHH
rename x316g2 wohnentf
rename x316f3 leibl

save `basisenkel', replace

use `einzelenkel', clear
append using `basisenkel'

sort fallnum kind enkel

foreach var of varlist enkel-wohnentf {
	local lab: variable label `var'
	local newlab: subinstr local lab "Einzelenkel: " "Enkel: ", all
	lab var `var' "`newlab'"
}

save `enkel', replace
restore

* Aufbereitung biologischer Kinder und deren Enkel
preserve 
use `enkel', clear
keep fallnum kind geburtsj
mvdecode geburtsj, mv(9997/9999=.a)
sort fallnum kind geburtsj
rename geburtsj grchbyr
by fallnum kind (grchbyr), sort: gen nofenkel = _N
by fallnum kind (grchbyr), sort: gen n = _n
reshape wide grchbyr, i(fallnum kind) j(n)

tempfile enkel
save `enkel' 

use `kinder', clear

mvdecode x304, mv(9997/9998=.a)
sort fallnum x304
rename x304 childbyr

mvdecode x309, mv(-1=. \ 7/8 = .a)
mvdecode x311, mv(9997/9998=.a \ -1=.)

// ACHTUNG: Das gibt es nur bis zum 4. Kind!
recode x309 (1=1) (2=0), gen(resident)
gen leaveyr = x311
replace leaveyr = childbyr if leaveyr==9995 // Geburtsdatum bei noch die Zusammengelebt


keep fallnum kind childbyr bio resident leaveyr

merge 1:1 fallnum kind using `enkel', assert(matched master)
gen enkeldata = _merge==3
drop _merge	

* Behalte nur biologische Kinder
keep if bio==1
* für biologische Kinder bestimme das älteste Kind

foreach var of varlist grchbyr* {
	rename `var' `var'_
}
rename enkeldata enkeldata_
rename bio bio_
rename kind kind_
rename childbyr childbyr_
rename resident resident_
rename leaveyr leaveyr_
rename nofenkel nofenkel_
sort fallnum kind_
ds grchbyr*_
reshape wide childbyr_ `r(varlist)' bio_ enkeldata_ leaveyr_ resident_ nofenkel_, i(fallnum) j(kind_)

* erstes Enkel
egen birth_ogc = rowmin(grchbyr*)
replace birth_ogc = .a if (enkeldata_1==1 | enkeldata_2==1 | enkeldata_3==1 | enkeldata_4==1 ///
						 | enkeldata_5==1 | enkeldata_6==1 | enkeldata_7==1 | enkeldata_8==1) & birth_ogc==.

* erstes Kind
egen birth_oc = rowmin(childbyr_*)
replace birth_oc = .a if birth_oc == .
* letztes Kind
egen birth_yc = rowmax(childbyr_*)
replace birth_yc = .a if birth_yc == .

* noch ein kind im HH
egen chinHH = rowmax(resident_*)
egen lastleaveyr = rowmax(leaveyr_*)

* Marker für Kinddaten verfügbar
gen kinddata = 1
* Marker für Enkelkinddaten verfügbar
gen enkeldata = (enkeldata_1==1 | enkeldata_2==1 | enkeldata_3==1 | enkeldata_4==1 ///
			   | enkeldata_5==1 | enkeldata_6==1 | enkeldata_7==1 | enkeldata_8==1) 

save `biokindermitenkel', replace
restore


* <<<<<< Vorbereitung (Kinder, Enkel) 
* (ende)
************************************************

************************************************************
* Basisvariablen >>>>>>
* (start)
mvdecode x300, mv(-1=. \ 97 99 = .a)
* Kinder  
recode x300 (1/9 = 1) (95=0) (.a=.a), gen(kinder)

* drop kinderlose
* drop if kinder==0 

clonevar sex = x1
clonevar birth = x2_3
mvdecode isced_08 isei88zp_08 , mv(-9=.a \ -1=.)
clonevar isced = isced_08
* ISEI 88 (letzter Beruf)
clonevar isei = isei88zp_08 
* ost-/west (Berlin wird zu westen kodiert)
recode bland (1/11 = 0 "West") (12/16=1 "Ost"), gen(ost)

* Vor Wiedervereinigung in welchem Teil Deutschlands gelebt
clonevar wherelived = x328
* wo aufgewachsen (bis zum 16)
clonevar wheregrewup = x327

* Bildungsvariable
fre x26
mvdecode x26 x28 x29, mv(-1=. \ 7/9 = .a)
mvdecode x27 x30, mv(-1=. \ 97/99 = .a)
mvdecode x27a, mv(-1=. \ 997/999 = .a) 

* ISCED Codierung
* http://www.gesis.org/fileadmin/upload/forschung/publikationen/gesis_reihen/gesis_methodenberichte/2006/06_08_Schroedter.pdf
* S. 36, S. 54 (MZ 2003/4) => ISCED 97
* Bildungsabschluss in Deutschland
capt drop schulab
gen schulab = .
replace schulab = 1 if inlist(x27,1,9) | x27a==995 | inrange(x27a,1,4) | x28==1 | x26==6   // kein Schulabschluss: A | J
replace schulab = 4 if inlist(x27,2,4) | (inrange(x27a,5,9) & inlist(x28,2,3)) // HS/VS/POS8: B | D
replace schulab = 5 if inlist(x27,3,5) | (inlist(x27a,10) & inlist(x28,2,3))  // RS/POS10
replace schulab = 6 if inlist(x27,6,7) | (inrange(x27a,11,21) & inlist(x28,2,3))  // ABI/FHR: C | E | F | G
replace schulab = 2 if inlist(x27,8) | (!inrange(x27a,1,4) & !inlist(x27a,.,995) & !inlist(x28, 1,2,3)) // ohne Angabe ob Schulabschluss
replace schulab = 3 if inlist(x27,8) | (!inrange(x27a,1,4) & x27a==.a & inlist(x28, 2,3)) // ohne Angabe zur Art Schulabschluss

* Beruflicher Abschluss
// 6 kategorien
capt drop berufab
gen berufab = .

replace berufab = 1 if x30==8 | x29==4 // kein beruflicher Abschluss
replace berufab = 4 if x30==1 		   // Anlernausb./Prak./BVJ
replace berufab = 5 if inlist(x30,2,3) // Lehre / Berufsfachschule
replace berufab = 6 if inlist(x30,4) // Meister/ Techn. / ver
replace berufab = 7 if inlist(x30,5,6) // Meister/ Techn. / ver

replace berufab = 2 if x29==.a // o.A. ob beruflicher Ab.
replace berufab = 3 if inlist(x30, .a,7) | inlist(x31,.a,5)    // o.A. zur Art beruflicher Ab.

replace berufab = 4 if x31==1 // in einem betrieb anglernt
replace berufab = 5 if x31==2 // längere Ausbildung gemacht
replace berufab = 5 if x31==3 // eine berufsbildende Schule besucht
replace berufab = 7 if x31==4 // hochschule

* ISCED nach MZ 2004
/*
ISCED 
1B	= 1
2B  = 2
2A  = 3
3B  = 4
3A  = 5
4A  = 6
5B  = 7
5A  = 8
n.a. = 99
*/
capt lab drop ISCED_skopek
lab def ISCED_skopek  1 "1B" 2 "2B" 3 "2A" 4 "3B" 5 "3A" 6 "4A" 7 "5B" 8 "5A" 99 "nicht bestimmbar" 

capt drop ISCED_skopek
gen ISCED_skopek = .
lab val ISCED_skopek ISCED_skopek
* 1B
replace ISCED_skopek = 1 if (inlist(berufab,1,2) & schulab==1) | (schulab==2 & berufab==1)
* 2B
replace ISCED_skopek = 2 if (inlist(berufab,.,1,2,3,4) & schulab==4) | ///
							(inlist(berufab,1,2,3,4) & schulab==3) | ///
							(inlist(berufab,3,4) & inlist(schulab,1,2))
* 2A
replace ISCED_skopek = 3 if (inlist(berufab,1,2,3,4) & schulab==5)
* 3B
replace ISCED_skopek = 4 if (inlist(schulab,1,2,3,4,5) & inlist(berufab,5))
* 3A
replace ISCED_skopek = 5 if (inlist(berufab,.,1,2,3,4) & schulab==6)
* 4A
replace ISCED_skopek = 6 if (inlist(schulab,6) & inlist(berufab,5))
* 5B
replace ISCED_skopek = 7 if (inlist(berufab,6))
* 5A
replace ISCED_skopek = 8 if (inlist(berufab,7))
* Nicht bestimmbar
replace ISCED_skopek = 99 if berufab==2 & schulab==2

tab ISCED_skopek isced_08 // die zwei abeichenden Fälle bei SKOPEK sind besser kodiert.

* <<<<<<< Basisvariablen 
* (ende)
************************************************************

************************************************************
* Eltern und deren Tod >>>>
* (start)
* 1. & 2. Nennung von Person bei der man aufgewachsen ist
mvdecode x7_1 x10a x10aa x7_2 x10b x10ab, mv(-1=.)
mvdecode x10a x10b, mv(7/8=.a)
mvdecode x10aa x10ab, mv(9997/9998=.a)

* Mutter (leibliche Mutter, Stiefmutter, Pflegemutter)
gen mother = .
gen deathmoth = .
gen ttdeathmoth = .

* 1. Nennung
replace mother = 1 if inlist(x7_1,1,3,5) // leibliche Mutter, Stiefmutter, Pflegemutter
replace deathmoth = x10a == 2 if mother==1 & !mi(x10a)
replace ttdeathmoth = x10aa - birth if deathmoth==1
replace ttdeathmoth = x10aa if inlist(x10aa,.a,.b,.c)
replace ttdeathmoth = .d if ttdeathmoth<0
replace ttdeathmoth = (intjahr - birth) if deathmoth==0 // rechtszensiert
* 2. Nennung
replace mother = 1 if inlist(x7_2,1,3,5) // leibliche Mutter, Stiefmutter, Pflegemutter
replace deathmoth = x10b == 2 if inlist(x7_2,1,3,5)  & !mi(x10b)
replace ttdeathmoth = x10ab - birth if deathmoth==1 & inlist(x7_2,1,3,5) 
replace ttdeathmoth = x10ab if inlist(x10ab,.a,.b,.c) & inlist(x7_2,1,3,5) 
replace ttdeathmoth = .d if ttdeathmoth<0
replace ttdeathmoth = (intjahr - birth) if deathmoth==0 // rechtszensiert

* Check
assert deathmoth==. if mother!=1
tab deathmoth mother, miss

tab ttdeathmoth deathmoth , miss

* Vater (ACHTUNG: hier fehlen häufiger Angaben als bei der Mutter)
gen father = .
gen deathfath = .
gen ttdeathfath = .

* 1. Nennung
replace father = 1 if inlist(x7_1,2,4,6) // leibliche Mutter, Stiefmutter, Pflegemutter
replace deathfath = x10a == 2 if father==1 & !mi(x10a)
replace ttdeathfath = x10aa - birth if deathfath==1
replace ttdeathfath = x10aa if inlist(x10aa,.a,.b,.c)
replace ttdeathfath = .d if ttdeathfath<0
replace ttdeathfath = (intjahr - birth) if deathfath==0 // rechtszensiert
* 2. Nennung
replace father = 1 if inlist(x7_2,2,4,6) // leibliche Mutter, Stiefmutter, Pflegemutter
replace deathfath = x10b == 2 if inlist(x7_2,2,4,6) & !mi(x10b)
replace ttdeathfath = x10ab - birth if deathfath==1 & inlist(x7_2,2,4,6)
replace ttdeathfath = x10ab if inlist(x10ab,.a,.b,.c) & inlist(x7_2,2,4,6)
replace ttdeathfath = .d if ttdeathfath<0
replace ttdeathfath = (intjahr - birth) if deathfath==0 // rechtszensiert

* Check
assert deathfath==. if father!=1
tab deathfath father , miss
tab ttdeathfath deathfath, miss

* ttdeath1p
gen death1p = max(deathfath,deathmoth) if !mi(deathfath) & !mi(deathmoth) & ttdeathfath<.a & ttdeathmoth<.a
gen ttdeath1p = min(ttdeathfath,ttdeathmoth) if death1p==1 & !mi(deathfath) & !mi(deathmoth) & ttdeathfath<.a & ttdeathmoth<.a
gen death2p = (deathfath==1 & deathmoth==1) if !mi(deathfath) & !mi(deathmoth) & ttdeathfath<.a & ttdeathmoth<.a
gen ttdeath2p = max(ttdeathfath,ttdeathmoth) if !mi(deathfath) & !mi(deathmoth) &  death2p==1 & ttdeathfath<.a & ttdeathmoth<.a

* Both parents dead
gen deathboth = death1p==1 & death2p==1 if !mi(deathfath) & !mi(deathmoth) & ttdeathfath<.a & ttdeathmoth<.a
gen ttdeathboth = max(ttdeath1p, ttdeath2p) if deathboth==1

* checks
assert death1p==1 if death2p==1
assert death2p==0 if death1p==0
assert ttdeath1p <= ttdeath2p if !mi(ttdeath1p) & !mi(ttdeath2p)
assert death1p==1 & death2p==1 if deathboth==1

* right censor cases
replace ttdeath1p = alter_08 if death1p==0
replace ttdeath2p = alter_08 if death2p==0
replace ttdeathboth = alter_08 if deathboth==0

* <<<<< Eltern und deren Tod
* (ende)
************************************************************

************************************************************
* Kinder & Enkel >>>>>
* (start)

* Datensatz mit biologischen Kindern und deren Kinder anspielen
merge 1:1 fallnum using `biokindermitenkel', assert(master matched) nogen 

* Alter der Kinder
local i = 1 
foreach var of varlist childbyr* {
	gen  childage_`i' = intjahr - `var'
	local i = `i' + 1
}

* Anzahl biologischer Kinder
egen numbiochild = anycount(bio_*), value(1)
* Anzahl co-residenter Kinder
egen numbiocoreschild = anycount(resident_*), value(1)
* Anzahl an Kindern mit Kindern
egen numbiochildenkel = rowtotal(nofenkel_*)

lab var numbiochild "Number of biological children"
lab var numbiocoreschild "Number of co-resident biolog. children"
lab var numbiochildenkel "Number of grandchildren from biolog. children"

 
* transition to non-active parenthood
* (= jüngestes biolog. Kind ist 16)
gen ynap = birth_yc + 16 
gen ttnap = ynap - birth
// remove zero ages
replace ttnap = .d if ttnap < 0
gen nap = ynap <= intjahr 
replace ttnap = (intjahr - birth) if nap==0 

* rekodiere unplausible Werte
* age at nap  (12+16)
replace ttnap = .d if ttnap < 28 & nap==1
drop ynap 

* transition to empty nest
recode chinHH (1=0) (0=1), gen(leavehome) 
gen ttleavehome = lastleaveyr - birth if leavehome==1
replace ttleavehome = .a if lastleaveyr == .a
replace ttleavehome = intjahr - birth if leavehome==0

* transition to first child (biolog.)
gen fchild = kinddata == 1
gen ttfchild = birth_oc - birth if fchild==1
replace ttfchild = .a if birth_oc == .a
replace ttfchild = intjahr - birth if fchild==0 
replace ttfchild = .d if ttfchild < 0
* age at first child 
replace ttfchild = .d if ttfchild < 12 & fchild==1

* at least 1 child age 16 at time of interview 
egen maxchage = rowmax(childage_*)
replace maxchage = .a if kinddata==1 & maxchage==.
gen sample_onechild16 = maxchage >= 16 if !mi(maxchage)
* alternatively: at least 1 child age 15 at time of interview 
gen sample_onechild15 = maxchage >= 15 if !mi(maxchage)

* Enkelkinder
gen desGPH = birth_ogc!=. // birth_ogc = .a => Enkel vorhanden, jedoch Geb.datum nicht bestimmbar
gen durGPH = (birth_ogc - birth) if desGPH==1
replace durGPH = .a if desGPH==1 & durGPH==.
* setze andere auf Rechtszensiert
replace durGPH = (intjahr - birth) if desGPH==0

* <<<<<< Kinder & Enkel 
* (ende)
************************************************************

************************************************************
* Erstehe und ihre Auflösung >>>>>>
* (start)

* ACHTUNG: 
* Für Personen, die mehr als 1 mal verheiratet waren, ist das Datum der Erstehe nicht bestimmbar.
* Für Personen, die mehr als 2 mal verheiratet waren, ist das Datum der Auflösung der Erstehe nicht bestimmbar.

* Wenn personen früher schon einmal verheiratet waren lässt sich das Datem der Erstheirat nicht bestimmen
mvdecode x200 x200c x201b, mv(7/9=.a \ -1=.)
mvdecode x200a_2 x200g_2 x200h_2 x200j_2 x200k_2, mv(-1=. \ 9997/9999=.a)
mvdecode x200ca x201c, mv(-1=. \ 97/99=.a)

* Verheiratet und Erstehe
gen marend = 0 if inlist(x200,1,2) & x200c==1 // befragter gab an, es sei die Erstehe
gen mar = 1 if inlist(x200,1,2) & x200c==1 
gen ttmar = x200a_2 - birth if mar==1
replace ttmar = .a if x200a_2==.a & mar==1

* Für Personen, die vorher genau einmal verheiratet waren:
* Ende der Erstehe = Jahr der Eheschließung der aktuellen Ehe - 1 Jahr
replace marend = 1 if inlist(x200,1,2) & x200c == 2 & x200ca==1
gen ttmarend = x200a_2 - 1 - birth  if inlist(x200,1,2) & x200c == 2 & x200ca==1
replace ttmarend = .a if x200a_2 == .a &  inlist(x200,1,2) & x200c == 2 & x200ca==1

* Marker für mehrfach vorher verheiratet (zur prüfung später)
gen multiplemars = (x200ca > 1 & x200ca < .)

* Geschieden und Erstehe
replace marend = 1 if x200==3 & x201b == 1 
replace ttmarend = x200g_2 - birth if x200==3 & x201b == 1 
replace ttmarend = .a if x200g_2==.a & x200==3 & x201b == 1 

* Für Personen, die Geschieden waren und genau einmal vorher verheiratet waren:
* Ende der Erstehe = Start aktuelle Ehe - 1 Jahr
replace marend = 1 if x200==3 & x201b == 2 & x201c==2
replace ttmarend = x200h_2 - birth if x200==3 & x201b == 2 & x201c==2
replace ttmarend = .a if x200h_2==.a & x200==3 & x201b == 2 & x201c==2

* Marker für mehrfach vorher verheiratet (zur prüfung später)
replace multiplemars = (x201b==2)

* Verwitwet und Erstehe
replace marend = 1 if x200==4 & x201b == 1 
replace ttmarend = x200j_2 - birth if x200==4 & x201b == 1 
replace ttmarend = .a if x200j_2==.a & x200==4 & x201b == 1 

* Für Personen, die verwitwet waren und genau einmal vorher  verheiratet waren:
* Ende der Erstehe = Start aktuelle Ehe - 1 Jahr
replace marend = 1 if x200==4 & x201b == 2 & x201c==2
replace ttmarend = x200k_2 - birth if x200==4 & x201b == 2 & x201c==2
replace ttmarend = .a if x200k_2==.a & x200==4 & x201b == 2 & x201c==2

* Ledige
replace mar = 0 if x200==5

* Rechtzensierungen 
replace ttmar = intjahr - birth if mar==0
replace ttmarend = intjahr - birth if marend==0

* <<<<<< Erstehe und ihre Auflösung  
* (ende)
************************************************************

************************************************************
* Rente & ET >>>>>>
* (start)
mvdecode x32 x169_2, mv(9997/9999=.a \ -1=.)
mvdecode x100, mv(8/9=.a \ -1=.)
mvdecode x113 x175, mv(9997/9999=.a \ -1=.)
mvdecode x101, mv(97/99=.a \ -1=.)
mvdecode x163_2, mv(9=.a \ -1=.) // ACHTUNG: wert 9 ist datenfehler, wird als Verweigerung interpretiert 

* Keinerlei Fragen zur Erwerbstätigkeit wurden gefragt, wenn x32==9995
recode x32 (min/2005 = 0) (9995=1) (.a=.a), gen(neveremp)
lab var neveremp "Nie hauptberuflich erwerbstätig gewesen"


* transition to first job
recode x32 (min/2005 = 1) (9995=0), gen(firstjob)
gen ttfirstjob = x32 - birth if firstjob==1
replace ttfirstjob = .a if x32==.a & firstjob==1
replace ttfirstjob = intjahr - birth if firstjob == 0
* age at first job
replace ttfirstjob = .d if ttfirstjob < 12 & firstjob==1

* ACHTUNG: Fragebogenfilter!
* Personen >= 60 
* wenn alter >= 60, dann wurde nach Rentenbezug gefragt (x100)
recode x100 (1=1) (2=0), gen(rente)
* Bis zu welchem Jahr hauptberuflich erwerbstätig? (= Datum der Verrentung)
gen exityr = x113 if rente == 1

* Personen < 60 | personen >= 60 die noch keine Pension beziehen
replace rente = .a if x101==.a & mi(rente)
* A: Vorruhestand (in rente)
replace rente = 1 if x101==1
replace exityr = x169_2 if x101==1 
* B: Arbeitslos (nicht in rente)
replace rente = 0 if x101==2 
* C: in Freistellungsphase der Altersteilzeit (in rente)
replace rente = 1 if x101==3
replace exityr = x163_2 if x101==3 
* D: Frührentner oder E: frühpensioniert (in rente)
replace rente = 1 if inlist(x101,4,5)
replace exityr = x175 if inlist(x101,4,5) // jahr bis zu dem man hauptberuflich tätig war
* F in Umschulung | Weiterbildung (nicht verrentet)
* G in Mutterschafts- | Erziehungsurlaub (nicht verrentet)
replace rente = 0 if inlist(x101,6,7)

/*
* H Hausfrau | Hausmann (kodiere als verrentet, wenn keine Bereitschaft für Aufnahme einer ET ist!)
replace rente = 1 if x101==8 & !inlist(x173,1,2)
replace exityr = x175 if x101==8 & !inlist(x173,1,2) // jahr bis zu dem man hauptberuflich tätig war
replace rente = 0 if x101==8 & inlist(x173,1,2)
*/
* H Hausfrau | Hausmann (kodiere als inaktiv/verrentet)
replace rente = 1 if x101==8 
replace exityr = x175 if x101==8 // jahr bis zu dem man hauptberuflich tätig war

/*
* J aus anderen Gründen nicht erwerbstätig (kodiere als verrentet, wenn keine Bereitschaft für Aufnahme einer ET ist!)
replace rente = 1 if x101==9  & !inlist(x173,1,2)
replace exityr = x175 if x101==9   & !inlist(x173,1,2) // jahr bis zu dem man hauptberuflich tätig war
replace rente = 0 if x101==9 & inlist(x173,1,2)
*/
* J aus anderen Gründen nicht erwerbstätig  (kodiere als inaktiv/verrentet)
replace rente = 1 if x101==9 
replace exityr = x175 if x101==9  // jahr bis zu dem man hauptberuflich tätig war


* Derzeit erwerbstätig
replace rente = 0 if inlist(x101,10,11)

* nehme die codierte Verrentung als Job-Exit event
* Dauer bis zum Ende der Erwerbstätigkeit (ab geburt)
gen ret = rente
gen ttret = exityr - birth 
replace ttret = .a if exityr == .a
replace ttret = (intjahr - birth ) if ret==0

* <<<<<< Rente & ET 
* (ende)
************************************************************

clonevar nofchildren = x300

************************************************************
* >>>>>> Schwere Krankheit
* (start)
mvdecode x514, mv(-1=. \ 9997/9999=.a)

gen ill = x514 != .
gen ttill = x514 - birth
replace ttill = .a if x514 == .a
replace ttill = (intjahr - birth ) if ill==0

* <<<<<< Schwere Krankheit
* (ende)
************************************************************

clonevar selfrhlth = x501
mvdecode selfrhlth, mv(-1 =. \ 7/8 = .a)

clonevar birthpartner = x201
mvdecode birthpartner, mv(-1 =. \ 9997/9999 = .a)

drop x1-f78_8o

************************************************************
* Sample selection & post-stratification weights

* 6205
count
assert _N==6205

* men and women
fre sex
/*
----------------------------------------------------------------
                   |      Freq.    Percent      Valid       Cum.
-------------------+--------------------------------------------
Valid   1 Männlich |       3133      50.49      50.49      50.49
        2 Weiblich |       3072      49.51      49.51     100.00
        Total      |       6205     100.00     100.00           
----------------------------------------------------------------
*/


* cohort variable
recode birth (1929/1938=1 "1929-1938") ///
			 (1939/1948=2 "1939-1948") ///
			 (1949/1958=3 "1949-1958") ///
			 , gen(cohort)


gen age = alter_08 



* one missing value in bland (recode to West)
li wherelived if bland==.
recode bland (11 12 13 14 15 16 = 2) (.=1) (else=1), gen(part2008)


recode wherelived (1=1 "East") (2=2 "West") (else=.), gen(part)	



* 6205
count


* men and women
fre sex
tab sex part 

/*

             | RECODE of wherelived
             |      (x328 - Vor
             | Wiedervereinigung in
             |     welchem Teil
        x1 - |     Deutschlands 
 Geschlecht  |      East       West |     Total
-------------+----------------------+----------
    Männlich |     1,025      1,974 |     2,999 
    Weiblich |     1,058      1,854 |     2,912 
-------------+----------------------+----------
       Total |     2,083      3,828 |     5,911


*/


***********************
* 2nd selection: age and cohort
***********************


* Age at time of first birth
gen ageochild = birth_oc - birth
* Age at time when oldest child is 14
gen ageochild14 = (birth_oc+14) - birth
* is a parent?
gen isparent = ageochild < .
gen child16plus = ageochild >= 16 & ageochild < .

* gen a pseudo weight for unweighted analyses
gen noweight = 1


* keep relevant variables
rename birth birthy 
rename intjahr inty 
recode neveremp (1 = 0) (0 = 1), gen(everpaid)
replace nofchildren = 0 if nofchildren==95

* EDU Variable 
recode ISCED_skopek (1 2 = 1 "low") (3 4 5 6 = 2 "middle") (7 8 = 3 "high") (. 99 = .), gen(EDU)


egen intymin = min(inty)
egen intymax = max(inty)

gen man = sex==1

* take design weights
rename intb08a7 aweight

* generate st-Variables for transition to grandparenthood 
* conditional on those who have a child of age 16 or older (for being compatibel with ESS/GGS)
* stset (unweighted!!)
stset durGPH if child16plus==1, f(desGPH) 
* keep only those cases who enter the risk set

***********************
* selection: 
* remove people where we do not know where they lived before reunification
* and people who were not living in Germany before reunification
* (note: about 4%, does not change to much)
* drop if part==.
***********************

* Mark different steps of sample selection (see above)
* "0" selection: only respondents born in West- or East-Germany before reunification
gen sampleSelect0 = part < .
* 1st selection
gen sampleSelect1 =sampleSelect0==1 &  (child16plus==1) & man < . 
* 2nd selection
gen sampleSelect2 = sampleSelect1==1 & inrange(age, ${lowerAgeLimit}, ${upperAgeLimit}) 
* 3rd selection
gen sampleSelect3 = sampleSelect2 &  ( _st==1)	& !(_t < 20 & _d==1)	// the latter term throws out highly inplausible grandparenthood ages below age 20


fre part
fre part if sampleSelect0 == 1
fre part if sampleSelect1 == 1
fre part if sampleSelect2 == 1
fre part if sampleSelect3 == 1
fre part if sampleSelect3 == 1 & _d==1

gen DEAS = 1

keep fallnum part EDU DEAS birthy inty* _* man age tt* fchild nap leavehome aweight death* mar* firstjob everpaid ret nofchildren sampleSelect*

// save ${prepared}\transition_sample_deas, replace
save ${prepared}/prepared_deas, replace
exit
