/*

Replication files 

Leopold, T., & Skopek, J. (2015). The Demography of Grandparenthood: An International Profile. Social Forces, 94(2), 801–832. https://doi.org/10.1093/sf/sov066

Data Preparation for European Social Survey (ESS).

*/

set more off
use "${ESS}", clear

* ADD Data from Latvia here!!!
append using "${ESS_Latvia}"

* No design weights for LV & RO
* hence, set weighting variable to 1
replace dweight = 1 if (cntry=="LV" | cntry=="RO") & dweight==.

* Sample Sizes
preserve
recode age (999=.)
replace age = floor(age)
* weighted age average
encode cntry, gen(c)

gen mAge_w = . 
foreach num of numlist 1/25 {
	sum age [aweight=dweight] if c==`num'
	replace mAge_w = `r(mean)' if c==`num'
}
format mAge_w %9.2f

recode inwmms (99=.)
recode inwyys (9999=.)
recode inwmme (99=.)
recode inwyye (9999=.)
gen intstart = ym(inwyys,inwmms)
gen intend = ym(inwyye,inwmme)
by cntry, sort: egen fields = min(intstart)
by cntry, sort: egen fielde = max(intend)
format %tm fields fielde
gen n = 1
collapse (sum) n (max) fields fielde mAge_w, by(cntry)
log using ${logdir}/totalsamplesize_ESS.smcl, replace
li cntry fields fielde n mAge_w, noobs clean
log close
restore

* Field periods
egen intymin = min(inwyys)
egen intymax = max(inwyye) if inwyye < 9999

* Gender
recode gndr (1=1) (2=0) (9=.), gen(man)

* Geburtsdatum
gen birthy = yrbrn if yrbrn < 7777
* Kinder
gen children = (bthcld==1) if bthcld < 7
replace children=1 if nbthcld >0 & nbthcld < 66

* Bildungsniveau
gen edu = edulvla if edulvla < 55
lab val edu edulvla

* Anzahl Enkelkinder (nur gefragt f¸r Personen FIRST CHILD BORN 1990 OR EARLIER)
gen fchildy = fcldbrn if fcldbrn < 6666	// code 6666 Not applicable, 7777 Refusal, 8888 Don't know, 9999 No answer as missings
gen ngc = ngchld if ngchld < 66

* Jahr in dem das erste Kind geboren wurde
gen fcy = fcldbrn if fcldbrn < 6666 // code 6666 Not applicable, 7777 Refusal, 8888 Don't know, 9999 No answer as missings

* Jahr in dem das letzte (j¸ngste) Kind geboren wurde
gen lcy = ycldbyr if ycldbyr < 6666 // code 6666 Not applicable, 7777 Refusal, 8888 Don't know, 9999 No answer as missings

* Jahr in dem das erste Enkelkind geboren wurde
gen fgcy = ygcdbyr if ygcdbyr < 6666 // code 6666 Not applicable, 7777 Refusal, 8888 Don't know, 9999 No answer as missings

* Interviewdatum (achtung: 99 fehlwerte)
gen iy = inwyye if inwyye < 9999


* Variable: evpdemp "Paid employment or apprenticeship at least 3 months 20 hours weekly" 
gen everpaid = evpdemp==1 if evpdemp < 7

mvdecode mnactic, mv(77 88 99 = .a)

capt drop active
* Those who are not retired?
* people declaring to be working
gen active = 1 if mnactic==1
* people being in education
replace active = 1 if mnactic==2
* people unemployed, but looking for job
replace active = 1 if mnactic==3
* people in community of military service
replace active = 1 if mnactic==7
* we treat other as being right censored 
replace active = 1 if mnactic==9

* Who is coded as retired?
* The actual retired
replace active = 0 if mnactic==6
* Those being permanently sick or disabled
replace active = 0 if mnactic==5
* people unemployed, but not looking for job
replace active = 0 if mnactic==4
* housewifes/men
replace active = 0 if mnactic==8

* Retired
capt drop retired ttretired
gen retired = active == 0 if !mi(active) 
gen ttretired = iy - birthy if retired == 0

mvdecode rtdsbyr pdjobyr, mv(6666 = . \ 7777 8888 9999 = .a)

replace ttretired = rtdsbyr - birthy if retired==1 & rtdsbyr > 1111 & rtdsbyr < .
replace ttretired = .a if rtdsbyr == .a & retired==1
replace ttretired = pdjobyr - birthy if retired==1 & ttretired==.

* Correct for people never had a paid job
replace everpaid = 0 if pdjobev==2 | rtdsbyr==0 | rtdsbyr==1111
replace everpaid = 1 if pdjobev==1 & retired == 1 & everpaid == .
replace everpaid = 1 if retired == 1 & everpaid == . & mnactic == 6
replace everpaid = 0 if retired == 1 & everpaid == . & mnactic == 8
replace retired = . if everpaid == 0
replace ttretired = . if everpaid == 0

* Some cases have missings because either interview date or birthdate is missing
assert mi(iy) | mi(birthy) if ttretired==. & retired == 0

* Rename
rename retired ret
rename ttretired ttret

* Jahr des ersten Jobs
gen yfjob = pdempyr if pdempyr < 6666 & everpaid==1

* Alter beim ersten Job
gen agefj = yfjob - birthy

* Alter bei Geburt des ersten Kindes
gen agefc = fcy - birthy
* Alter bei Geburt des letzten Kindes
gen agelc = lcy - birthy
* Alter bei Geburt des ersten Enkelkindes
* (fehlwert f¸r personen ohne enkelkind bzw. ohne geburtsangabe beim enkelkind)
gen agefgc = fgcy - birthy

* Alter bei interview ende
* (evtl besser age nehmen)
gen ageatint = iy - birthy


* First marriage
gen mar = evmar==1 if evmar < 7
gen agefirstmar = maryr - birthy if maryr < 7777 & mar==1
gen ttfirstmar = agefirstmar 
replace ttfirstmar = ageatint if mar==0

* Survival-Times
* transition to first job 
gen ttfirstjob = agefj 
gen firstjob = agefj < . if !inlist(pdempyr,7777,8888,9999) // important: do not censor dkn/refusals  
replace ttfirstjob = ageatint if firstjob==0 

* transition to Retirement (at risk: everpaid==1 & permsick==0)
/*
gen ttret = ageret if everpaid==1 & permsick==0
gen ret = ageret < . if everpaid==1 & permsick==0 & !inlist(rtdsbyr,7777,8888,9999) // important: do not censor dkn/refusals
replace ttret = ageatint if ret==0 & everpaid==1 & permsick==0
*/

* transition to first time parenthood (at risk: neverpaid==0)
gen ttph1 = agefc
gen ph1 = agefc < . if !inlist(fcldbrn,7777,8888,9999) // important: do not censor dkn/refusals
replace ttph1 = ageatint if ph1==0 

gen ttfchild = ttph1
gen fchild = ph1

* transition to last time parenthood (at risk: ph1==1)
gen ttph2 = agelc if ph1==1
gen ph2 = agelc < . if ph1==1 
replace ttph2 = ageatint if ph2==0

* transition to non-active parenthood
* (= j¸ngestes Kind ist 16)
gen ynap = max(fcy, lcy) + 16 
gen ttnap = ynap - birthy 
gen nap = ynap <= iy 
replace ttnap = ageatint if nap==0 

gen fchild1990earlier = fchildy <= 1990
replace fchild1990earlier = 1 if agefgc < .



* Education variable: 
recode edulvla (1 2 = 1 "low") ///
			   (3 4 = 2 "middle") ///
			   (5 6 = 3 "high"), gen(EDU) 
replace EDU = . if !inlist(EDU, 1,2,3)

gen ISCEDgt4 = edulvla > 4 if edulvla < 55
gen ISCEDlt3 = edulvla < 3 if edulvla < 55

* Relative Education
recode birthy (min/1949 = 1 "< 1950") /// 
			 (1950/1969 = 2 "1950/69") ///
			 (1970/max = 3 "1970+") ///
			 , gen(cohort)
tab cntry cohort, miss
* recode 
clonevar isced = edulvla
replace isced = . if isced >=55

by cntry cohort, sort: egen iscedpc50 = pctile(isced), p(50)
gen EDUrel = 0 if isced <= iscedpc50 & !mi(iscedpc50) & !mi(isced)
replace EDUrel = 1 if isced > iscedpc50 & !mi(iscedpc50) & !mi(isced)

fre EDUrel

tab cntry EDUrel if cohort==1, row nofreq
tab cntry EDUrel if cohort==2, row nofreq
tab cntry EDUrel if cohort==3, row nofreq

* Country
encode cntry if cntry!="LV" & cntry!="RO", gen(c)
replace c = 35 if cntry=="LV"
replace c = 36 if cntry=="RO"
lab def c 35 "LV" 36 "RO", modify
			  
* transition to GPH (at risk: fchild1990earlier == 1)
gen ttgph = agefgc if fchild1990earlier == 1
* attention! this was changed!!!
gen gph = agefgc < . if fchild1990earlier == 1 & !inlist(ygcdbyr,7777,8888,9999) // important: do not censor dkn/refusals
replace ttgph = ageatint if gph==0 & fchild1990earlier == 1 & !inlist(ygcdbyr,7777,8888,9999) // important: do not censor dkn/refusals

* Transition to Grandparenthood
gen sample = fchild1990earlier==1 & children==1 // added: children==1 !!!
stset ttgph [iweight=dweight] if sample==1, f(gph) 

* Number of children
mvdecode nbthcld, mv(66=. \ 77 88 99=.a)
clonevar nofchildren = nbthcld



* recode age
replace age = floor(age)
recode age (999=.)
	 
/*
Country codes: 

Austria AT
Belgium BE
Bulgaria BG
Cyprus CY
Czech Republic CZ
Denmark DK
Estonia EE
Finland FI
France FR
Germany DE
Greece GR
Hungary HU
Iceland IS
Ireland IE
Israel IL
Italy IT
Luxembourg LU
Netherlands NL
Norway NO
Poland PL
Portugal PT
Romania RO
Russia RU
Slovakia SK
Slovenia SI
Spain ES
Sweden SE
Switzerland CH
Ukraine UA
United Kingdom GB
Turkey TR
*/

* restrict to countries under study only!
/*
Poland
Sweden
Spain
Denmark
Austria
Switzerland
Latvia
Slovenia
Netherlands
Finland
Ukraine
Great Britain
Portugal
*/
keep if inlist(cntry, "PL", "SE", "ES") | inlist(cntry, "DK", "AT", "CH") | inlist(cntry, "LV", "SI", "NL") | inlist(cntry, "FI", "UA", "GB", "PT")

** countries and cases
fre cntry 


* Mark different steps of sample selection (see above)
* 1st selection
gen sampleSelect1 = (fchild1990earlier==1 & children == 1) & man < . 
* 2nd selection
gen sampleSelect2 = sampleSelect1 &  inrange(age, ${lowerAgeLimit}, ${upperAgeLimit})
* 3rd selection
gen sampleSelect3 = sampleSelect2 &  (!(ngc ==6 & fchildy > 1990 & fchildy < .) & _st==1) & !(_t < 20 & _d==1)	// the latter term throws out highly inplausible grandparenthood ages below age 20	


* check
fre cntry if sampleSelect1==1
fre cntry if sampleSelect2==1
fre cntry if sampleSelect3==1

gen ESS = 1

save ${prepared}/prepared_ess, replace



