/*

Replication files 

Leopold, T., & Skopek, J. (2015). The Demography of Grandparenthood: An International Profile. Social Forces, 94(2), 801–832. https://doi.org/10.1093/sf/sov066

Data Preparation for Gender and Generations Survey (GGS).

*/
run init
*****************
* 1 Germany     *
*****************
/*
Variables: 
asex 	sex
aage 	age at interview
abyear  year of birth

amonth  interview month
ayear	interview year

aeduc	highest educational level (ISCED)
a150m a150y month & year of achieving this degree

aactstat	activity status (employed, retired, ...)
aparstat current partner status
amarstat marital status
ankids	number of children respondent
ahhtype Household type Respondent

              storage  display     value
variable name   type   format      label      variable label
-----------------------------------------------------------------------------------------
a238            byte   %26.0g      a238       Number of grandchildren
a239am          byte   %62.0g      a239am     Mnth of birth of the oldest grandchild
a239ay          int    %26.0g      a239ay     Yr of birth of the oldest grandchild
a239bm          byte   %62.0g      a239bm     Mnth of birth of the only grandchild
a239by          int    %26.0g      a239by     Yr of birth of the only grandchild
a240m           byte   %62.0g      a240m      Mnth of birth of the youngest grandchild
a240y           int    %26.0g      a240y      Yr of birth of the youngest grandchild
a241u           float  %26.0g      a241u      Time unit of help
a242a           byte   %26.0g      a242a      Any great grandchildren
a242b           byte   %26.0g      a242b      Number of great grandchildren


*/


capt program drop prepare_hhgrid
program define prepare_hhgrid
	syntax, [exclude(namelist)]
	keep arid ayear acountry ahg1_* ahg3_* ahg4_* ahg5_* ahg6y_* ahg7y_* ahg8_*  
	local vars ahg1_ ahg3_ ahg4_ ahg5_ ahg6y_ ahg7y_ ahg8_
	if "`exclude'" != "" local vars: list vars - exclude
	foreach var in `vars' {
		local `var'lab: variable label `var'1
	}
	reshape long ahg1_ ahg2_ ahg3_ ahg4_ ahg5_ ahg6y_ ahg7y_ ahg8_, i(arid)
	foreach var in `vars' {
		local lab: subinstr local `var'lab " 1" ""
		lab var `var' "`lab'"
	}
	* drop empty rows
	drop if mi(ahg1_)
	drop _j
end

capt program drop prepare_nonresident_children
program define prepare_nonresident_children
	keep ayear arid acountry  a209 a211a a211b_* a212_* a213_* a215_* a216y_* a217y_*   a220m_* a220y_*   
	local vars a211b_ a212_ a213_ a214y_ a215_ a216y_ a217y_ a220y_ 
	foreach var in `vars' {
		local `var'lab: variable label `var'1
	}
	reshape long `vars', i(arid)
	foreach var in `vars' {
		local lab: subinstr local `var'lab " 1" ""
		lab var `var' "`lab'"
	}
	* drop empty rows
	egen nomiss = rownonmiss(*_)
	drop if nomiss==0
	drop nomiss
	* consider relation typ 2-6 as "children"
	* 2 biological child with the current partner/spouse
	* 3 biological child with former partner or spouse
	* 4 stepchild
	* 5 adopted child
	* 6 foster child
	gen resident = 0
	clonevar sex = a212_
	recode a213_ (1=3) (2=5) (3=6), gen(relation)
	replace relation = 2 if a215_ ==1
	clonevar byr = a216y_ 
	clonevar death = a211b_
	clonevar deathyr = a217y_
	clonevar leaveyr = a220y_
	
	gen age = byr if mi(byr)
	replace age = ayear - byr if !mi(byr)
	replace age = .a if death==1
	lab var sex "Child: sex"
	lab var death "Child: child is dead"
	lab var deathyr "Child: year of death"
	lab var deathyr "Child: year of death"
	lab var leaveyr "Child: year of leaving"
	lab var age "Child: age"
	lab var byr "Child: year of birth"
	lab var resident "Child: co-resident"
	
	keep arid ayear acountry resident-age
end

capt program drop prepare_nonresident_stepchildren
program define prepare_nonresident_stepchildren
	keep arid ayear acountry  a226 a228a a228b_* a229_* a230y_* a231_* a232y_* a233y_*  a234y_* a235h_* a235t_* a236u_* a237_*
	local vars a228b_ a229_ a230y_ a231_ a232y_ a233y_ a234y_ a235h_ a235t_ a236u_ a237_
	foreach var in `vars' {
		local `var'lab: variable label `var'1
	}
	reshape long `vars', i(arid)
	foreach var in `vars' {
		local lab: subinstr local `var'lab " 1" ""
		lab var `var' "`lab'"
	}
	* drop empty rows
	egen nomiss = rownonmiss(`vars')
	drop if nomiss==0
	drop nomiss
	
	* consider relation typ 2-6 as "children"
	* 2 biological child with the current partner/spouse
	* 3 biological child with former partner or spouse
	* 4 stepchild
	* 5 adopted child
	* 6 foster child
	gen resident = 0
	clonevar sex = a229_
	gen relation = 4 
	clonevar byr = a230y_ 

	clonevar stephh = a231_
	clonevar death = a228b_
	
	clonevar deathyr = a233y_
	clonevar leaveyr = a234y_
	
	gen age = byr if mi(byr)
	replace age = ayear - byr if !mi(byr)
	replace age = .a if death==1
	
	lab var sex "Child: sex"
	lab var death "Child: child is dead"
	lab var deathyr "Child: year of death"
	lab var deathyr "Child: year of death"
	lab var leaveyr "Child: year of leaving"
	lab var age "Child: age"
	lab var byr "Child: year of birth"
	lab var resident "Child: co-resident"
	
	keep arid ayear  acountry resident-age
end

capt program drop prepare_consolidated_children
program define prepare_consolidated_children
	keep arid acountry  a251_* a252_* a253y_* a254_* a255y_* a256_*
	local vars a251_ a252_ a253y_ a254_ a255y_ a256_ 
	foreach var in `vars' {
		local `var'lab: variable label `var'1
	}
	reshape long `vars', i(arid)
	foreach var in `vars' {
		local lab: subinstr local `var'lab " 1" ""
		lab var `var' "`lab'"
	}
	* drop empty rows
	egen nomiss = rownonmiss(`vars')
	drop if nomiss==0
	drop nomiss
end

capt program drop prepare_reschildren
program define prepare_reschildren
	* consider relation typ 2-6 as "children"
	* 2 biological child with the current partner/spouse
	* 3 biological child with former partner or spouse
	* 4 stepchild
	* 5 adopted child
	* 6 foster child
	keep if inrange(ahg3_,2,6)
	gen resident = 1
	clonevar sex = ahg4_
	clonevar age = ahg5_
	clonevar byr = ahg6y_

	clonevar relation = ahg3_
	lab var sex "Child: sex"
	lab var age "Child: age"
	lab var relation "Child: relation to child"
	lab var byr "Child: year of birth"
	lab var resident "Child: co-resident"
	
	keep arid ayear  acountry resident-relation
end

* Program for adding prepared child data
* Base: consolidated data
capt program drop add_children_data
program define add_children_data
	
	preserve 
		keep arid ayear acountry a250 a251_* a252_* a253y_* a254_* a255y_* a256_*
		keep if a250==1 // keep only cases having children in the consolidated grid
		local vars a251_ a252_ a253y_ a254_ a255y_ a256_ 
		foreach var in `vars' {
			local `var'lab: variable label `var'1
		}
		reshape long `vars', i(arid)
		foreach var in `vars' {
			local lab: subinstr local `var'lab " 1" ""
			lab var `var' "`lab'"
		}
		* drop empty rows
		egen nomiss = rownonmiss(`vars')
		drop if nomiss==0
		drop nomiss
		drop a250
		
		clonevar death = a254_
		clonevar deathyr = a255y_
		
		clonevar sex = a252_
		clonevar byr = a253y_
		gen age = ayear - a253y_ if !mi(byr)
		replace age = .a if byr==.
		replace age = . if death==1
		clonevar relation = a251_
		
		gen resident = a256_==1
		* drop stepchildren, adopted children, foster children
		drop if inlist(a251_,3,4,5)
		
		// * drop missings in birth year
		// drop if mi(byr) 
			
		* Mark dead children who survived up to year 16
		* (note: variable is . if year of birth or year of death or both is missing)
		gen survivedto16 = cond(death==1,cond(byr-deathyr<=-15,1,cond(byr-deathyr==.,.,0)),1) 
		* retrict to children who survied up to age 16 
		// keep if survivedto16==1  

		* Prepare non active parenting
		* year of leave; code year of death for children who died
		// gen lyr = cond(!mi(leaveyr),leaveyr,cond(!mi(deathyr),deathyr,.)) 
		
		// lab var lyr "child: leaving year (incl. deaths)"
		keep arid acountry resident sex age byr relation death deathyr survivedto16 
		foreach var of varlist 	resident sex age byr relation death deathyr survivedto16 {
			rename `var' ch`var'
		}
		by arid (chbyr), sort: gen chnum = _n
		by arid (chbyr), sort: gen j= _n
		order chnum, after(acountry)
		lab var chnum "child number"
		reshape wide chnum chresident chsex chage chbyr chrelation chdeath chdeathyr chsurvivedto16 , i(arid) j(j)
		* year when child is 16 (. for died )
		/*	
		gen child16yr = byr + 16 // year may be in the future here
		// assert child16yr<=ayear if !mi(child16yr)
			
		by arid, sort: egen childhh = max(resident)
		by arid, sort: egen childbelow16hh = max(age<16)
		by arid, sort: egen lastleaveyr = max(lyr)
		by arid, sort: egen ychild16yr = max(child16yr)
		by arid, sort: egen child16plus = max(age>=16)
		by arid, sort: egen bychild = max(byr)
		by arid, sort: egen bochild = min(byr)
			
		replace ychild16yr = . if ychild16yr > ayear 
			
		* gen ageatleave = leaveyr - byr
		gen NAPyr = min(ychild16yr, lastleaveyr, ayear)
		gen NAP = (ychild16yr<=ayear) | (lastleaveyr<=ayear)
			
		keep arid acountry bychild child16plus ychild16yr lastleaveyr childbelow16hh childhh bochild NAP*
		*/
		
		duplicates drop arid , force
		isid arid
					
		tempfile child
		save `child'

	restore

merge 1:1 arid acountry using `child', assert(master matched) keep(master matched) nogen

// leaving home data
// get latest leaving home date of biological children
gen lastleave = 0
foreach num of numlist 1/20 {
	capt confirm variable a213_`num'
	if _rc > 0 continue
	replace lastleave = a220y_`num' if a213_`num'==1 & /// only bio children
									a220y_`num' > lastleave & /// 
									!mi(a220y_`num') 

}
// recode no move out data (=also missing for refusals/dkn's)
replace lastleave = . if lastleave == 0

end 

* Program for preparing grandparenthood variables
capt program drop prep_gph_variables
program define prep_gph_variables
	gen grandc = a238>0 if a238 < . // number of grandchildren
	replace grandc = .a if a238==.a
	gen gphyr = a239ay // gph: year of birth of oldest grandchild 
	* if there is only 1 grandchild, then use variables of the only grandchild
	replace gphyr = a239by if a238==1
end

* Program for preparing retirement variables
capt program drop prep_ret_variables
program define prep_ret_variables
	/*
	gen retired = (a870 == 5)
	gen retiredyr = a871y if retired==1
	gen retWorkBefore = a873==1 if retired==1
	*/
		* Attention: If questions a810 about intention to start a job/business for unemployed is missing
	* generate this variable under the following assumption: 
	* Assume that below age 55 respondent is looking for job if older not anymore
	capt confirm variable a810
	if _rc > 0 {
		gen 	a810 = 1 	if aage > 55 & aage < .
		replace a810 = 4 	if aage <=55
	}
	* Attention: if variable a831 ("Any paid work in the last 7 days ending last Sunday") is missing
	* generate this variable under the following assumption: 
	* no paid work in the last 7 days
	capt confirm variable a831 
	if _rc > 0 {
		gen a831 = 2 
	}
	* Attention: if variable a8821 (job before getting ill/disabled) is missing
	* generate this variable under the following assumption
	* had job before getting ill/disabled
	capt confirm variable a821
	if _rc > 0 {
		gen a821 = 1 
	}
	
	* Variable conformity check
	assert inrange(a801,1,10) | mi(a801) // current activity
	assert inrange(a810,1,4) | mi(a810) // Intention to take a job or start a business for currently unemployed
	assert inlist(a815,1,2) | mi(a815) // job/business before education/vocational training
	assert inlist(a831,1,2) | mi(a831) // any paid job in the last 7 days ...
	assert inlist(a825,1,2) | mi(a825) // job/business before homemaking
	assert inlist(a821,1,2) | mi(a821) // job/business before illness
	
	* Did respondent ever paid labor?
	capt drop everpaid
	* everpaid? => currently working, hlping family member in family business, unemployed, retired, on maternity leave, military service	
	gen everpaid = inlist(a801, 1, 2, 3, 5,6, 9) if !mi(a801)
	* if 8=looking after family, ever paid only if a job was done directly before
	replace everpaid = 1 if a801==8 & a825==1
	* ill or disables for a long time or permanently, everpaid if job before
	replace everpaid = 1 if a801==7 & a821==1
	* other, everpaid = 1 if did any paid work in the 7 days ending last Sunday, either as an employee or self-employed
	replace everpaid = 1 if a801==10 & a831==1 	
	* students/pupils/vocational trainers are coded everpaid if the had an employment before studying
	replace everpaid = 1 if a801==4 & a815==1
	
	
	* Define retirement/inactivity status
	capt drop ret
	* A) who is not retired, still active? 
	* a801: currenty activity status
	* 1  employed or self-employed
	* 2  helping family member in a family business or a farm
	* 3  unemployed AND not exclud to look for a job/business (i.e. not reporting "1 definitively not" in a810)!
	* 4  student, in school, in vocational training if had ever paid
	* 6  on maternity leave, parental leave or childcare leave
	* 9  in military service or social service
	* 10 other and did paid work in the 7 days ending last Sunday
	gen ret = 0 if inlist(a801,1,2,4,6,9) & (everpaid==1 & !mi(everpaid)) 
	replace ret = 0 if (a801==3 & a810!=1) & (everpaid==1 & !mi(everpaid)) 
	replace ret = 0 if (a801==10 & a831==1) & (everpaid==1 & !mi(everpaid))
	* B) Not active, already retired? 
	* 3 unemployed and definitively not looking for job/business
	* 5 retired
	* 7 ill/disabled for a long time
	* 8 homemakers (who had ever paid job)
	* (10 other who did nont paid work in the 7 days ending last sunday) => those are defined as never been in paid work
	replace ret = 1 if (a801==3 & a810==1) & (everpaid==1 & !mi(everpaid)) 
	replace ret = 1 if (a801==5) & (everpaid==1 & !mi(everpaid)) 
	replace ret = 1 if (a801==7) & (everpaid==1 & !mi(everpaid)) 
	replace ret = 1 if (a801==8) & (everpaid==1 & !mi(everpaid)) 
	
	* check: no missing for variable ret for those how ever had paid job
	assert everpaid!=1 if ret==.
	
	* reconstruct time of leaving labor force (= time of getting inactive/retired)
	capt drop ttret
	* for those who are retired
	gen ttret = a871y - abyear if ret == 1 
	* for those who are not retired (set interview date)
	replace ttret = ayear - abyear if ret == 0
end
* Keep only selected variables
capt program drop keep_relevant_variables
program define keep_relevant_variables
	egen intymin = min(ayear)
	egen intymax = max(ayear)
	
	keep acountry arid aweight* inty* asex aage amonth ayear abyear aeduc aactstat aparstat amarstat ankids ayear ahhsize ahhtype ///
	 a870 a871y a873 /// consolidated activity
	 ret ttret everpaid /// retirement
	 grandc gphyr /// grandparenthood
	 ch* lastleave /// children 
	 mar* /// marriage data
	 a510 a511 a512 a530 a531 a532 a552 // death of parents
end

capt program drop add_marriage_data
program define add_marriage_data
	preserve
	tempfile mar
	* Prepare partnership history
	keep arid acountry a333 a335a_* a343_* a344y_* a335y_* a349a_* a349y_*
		
	reshape long a335a_ a335y_ a349a_ a343_ a344y_ a349y_, i(arid) j(pn)
	* drop empty rows
	egen nomiss = rownonmiss(*_)
	drop if nomiss==0
	drop nomiss
	* keep only if there are former partners
	keep if a333==1
	* keep only marriages
	keep if a335a_==1
	drop a333 a335a_

	rename a335y_ maryr 
	rename a349a_ mardiv
	rename a349y_ mardivyr
	rename a343_  marsepreason
	rename a344y_ marsepyr
	drop pn

	by arid (maryr mardivyr), sort: gen j = _n
	by arid (maryr mardivyr), sort: gen marnum = _n
	order marnum, after(acountry)
	reshape wide marnum maryr mardiv mardivyr marsepreason marsepyr, i(arid) j(j)

	save `mar'
	restore
	
	* currently married if yes to a372a
	gen mar = a372a==1
	gen maryr = a372by if mar==1

	merge 1:1 arid acountry using `mar', assert(matched master) keep(matched master) nogen
end


/*

	
	
	stset ttret if aage > 50, f(ret)
	sts graph, by(asex)
	
*/


* 1. Germany
use ${wave1_germany}, clear
* recode a238 from .a to 0 if there are no kids
replace a238 = 0 if a238==.a & ankids==0
// recode a238 (.a=0) // obviously wrongly coded
prep_gph_variables
prep_ret_variables
add_children_data
add_marriage_data
keep_relevant_variables
save ${prepared}/germany, replace

* 2. Bulgaria
use ${wave1_bulgaria}, clear
* a211a & a228a is missing => reconstruct
egen a211a = anymatch(a211b_*), values(1)
recode a211a (1=2)
egen a228a = anymatch(a228b_*), values(1)
recode a228a (1=2)
prep_gph_variables
prep_ret_variables
add_children_data
add_marriage_data
keep_relevant_variables
save ${prepared}/bulgaria, replace

* 3. Estonia
use ${wave1_estonia}, clear
* recode a238 from .a to 0 if there are no kids
replace a238 = 0 if a238==.a & ankids==0
// recode a238 (.a=0) // obviously wrongly coded
prep_gph_variables
prep_ret_variables
add_children_data
add_marriage_data
keep_relevant_variables
save ${prepared}/estonia, replace

* 4. France
use ${wave1_france}, clear
* recode apprenticeship or paid training to employed
recode a801 (1501 = 1 )
// Recode divorce variables
* 1501 divorced or dissolved pacs => yes!
* 1502 about to divorce  => yes!
foreach var of varlist a349a_* {
	recode `var' (1501 1502 =1)
}

prep_gph_variables
prep_ret_variables
add_children_data
add_marriage_data
keep_relevant_variables
save ${prepared}/france, replace

* 5. Georgia
use ${wave1_georgia}, clear

prep_gph_variables
prep_ret_variables
add_children_data
add_marriage_data
keep_relevant_variables
save ${prepared}/georgia, replace

* 6. Hungary
use ${wave1_hungary}, clear

* Recode variable for willingnes to start a job/business in next 3 years for the unemployed
recode a810 (1601 = 1) (1602= 4)

prep_gph_variables
prep_ret_variables
add_children_data
add_marriage_data
keep_relevant_variables
save ${prepared}/hungary, replace

/* Italy removed from the analysis as sample is too young
* 7. Italy
use ${wave1_italy}, clear
gen a511 = -54 // not available
gen a531 = -54 // not available
prep_gph_variables
prep_ret_variables
add_children_data
add_marriage_data
keep_relevant_variables
save ${prepared}\italy, replace
*/

* 8. lithuania
use ${wave1_lithuania}, clear
prep_gph_variables
prep_ret_variables
add_children_data
add_marriage_data
keep_relevant_variables
save ${prepared}/lithuania, replace

/*
* 9. netherlands (excluded since almost no life course data to marriage, retirement, leaving home, etc available)
use ${wave1_netherlands}, clear

* ATTENTION: No extra date for marriage & divorce 
* take start of living together as proxy!
gen a335y_1 = a334y_1
gen a335y_2 = a334y_2
gen a335y_3 = a334y_3
gen a335y_4 = a334y_4
gen a335y_5 = a334y_5
gen a335y_6 = a334y_6
gen a335y_7 = a334y_7

gen a349y_1 = a344y_1
gen a349y_2 = a344y_2
gen a349y_3 = a344y_3
gen a349y_4 = a344y_4
gen a349y_5 = a344y_5
gen a349y_6 = a344y_6
gen a349y_7 = a344y_7

* ATTENTION: no leaving home data
* no a220_y => gen and set to missing
foreach num of numlist 1/11 {
	gen a220y_`num' = .
}
prep_gph_variables
prep_ret_variables
add_children_data
add_marriage_data
keep_relevant_variables
assert lastleave==. // not asked in netherlands
save ${prepared}\netherlands, replace
*/

* 10. romania
use ${wave1_romania}, clear
prep_gph_variables
prep_ret_variables
add_children_data
add_marriage_data
keep_relevant_variables
save ${prepared}/romania, replace

* 11. Russia
use ${wave1_russia}, clear
* recode working pensioners to employed (in Russia pension and working is decoupled)
recode a801 (1201 = 1)

recode a238 (.a=0) // obviously wrongly coded
// here not this: replace a238 = 0 if a238==.a & ankids==0

prep_gph_variables
prep_ret_variables
add_children_data
add_marriage_data
keep_relevant_variables
save ${prepared}/russia, replace

* 12. Belgium
use ${wave1_belgium}, clear
* a349a_* => "got divorced" one additional item, 2301 "Still in the divorce procedure"
* recode to 1 = yes
foreach var of varlist a349a_* {
	recode `var' (2301 = 1)
}
* ATTENTION: a238 number of grandchildren
* there is only a very low fraction of people answering 0, but a very high fraction of .a no response / not applicable
* Obviously, this question was asked in a different way compared to other countries or there is a coding error
* hence, recode .a to 0 

recode a238 (.a=0) // obviously wrongly coded
// here not this: replace a238 = 0 if a238==.a & ankids==0


prep_gph_variables
prep_ret_variables
add_children_data
add_marriage_data
keep_relevant_variables
save ${prepared}/belgium, replace

* 13. Norway
use ${wave1_norway}, clear
* amarstat : 2001 "marital disruption" no distinction between separation and divorce possible with norwegian data
* a343_*: "how partership # ends" 2001 still a couple but moved apart 
* no divorce variables! => a349a_*
* artifically generate those variables
foreach num of numlist 1/5 {
	gen a349a_`num' = .
	gen a349y_`num' = .

}
/*
tab a801 asex if aage>=65, miss col nofreq
*/
prep_gph_variables
prep_ret_variables
add_children_data
add_marriage_data
keep_relevant_variables
save ${prepared}/norway, replace



/*
 Generate a pooled dataset
*/
run init
use ${prepared}/germany, clear
foreach c in bulgaria estonia france georgia hungary  /// italy
			 lithuania romania russia belgium norway {
	append using "${prepared}/`c'.dta"
}
// 115363
count

* repair
lab def acountry 25 "Lithuania", modify

* Weights for netherlands
* replace aweight = aweight_1802 if acountry == 18

* Sample selection variable: One biological child age 16 or older
gen child16plus = 0
foreach var of varlist chage* {
	replace child16plus = 1 if `var'>=16 & !mi(`var')
}	
* Date of First birth
gen fbirthyr = chbyr1
foreach var of varlist chbyr* {
	replace fbirthyr = `var' if `var' < fbirthyr 
} 
	
* Birthcohort
recode abyear (min/1939 = 1 "< 1940") /// 
			 (1940/1949 = 2 "1940/49") ///
			 (1950/1959 = 3 "1950/59") ///
			 (1960/1969 = 4 "1960/69") ///
			 (1970/max = 5 "1970+"), gen(cohort)
* Education
recode aeduc (1501 = 0 "ISCED 0 pre-primary") /// 
			 (1502 = 1 "ISCED 1 primary") /// 
			 (2=2 "ISCED 2 lower sec") ///
			 (1503 1504 1505 = 3 "ISCED 3 upper sec") /// 
			 (4=4 "ISCED 4 post second. non-tert.") ///
			 (1506 1507 1701 1702 1703 = 5 "ISCED 5 first stage of tertiary") ///
			 (6=6 "ISCED 6 second state of tertiary") ///
			 (1101 = 0) (1407 1408 = -5 "still in edu") (1409 = -6 "other") (.d=.d "unkown"), ///
			 gen(ISCEDha) 
* EDU Variable 
recode ISCEDha (0 1 2 = 1 "low") (3 4 = 2 "middle") (5 6 = 3 "high") (.d -5 -6 = .), gen(EDU)

gen ISCEDgt4 = ISCEDha > 4 if ISCEDha >= 0 & !mi(ISCEDha)
gen ISCEDlt3 = ISCEDha < 3 if ISCEDha >= 0 & !mi(ISCEDha)


* Man variable
gen man = asex==1
			 
* Tabs
fre acountry	 

* Grandparenting
tab acountry grandc , miss
tab acountry grandc, row nofreq
* age 
tabstat asex aage grandc   child16plus [aweight=aweight], by(acountry) format(%9.2f)

tabstat aage [aweight=aweight], by(acountry) format(%9.2f) stats(mean p25 p50 p75)
// => variable wrongly coded for Russia, Germany, Estonia

*****************************************
* Sizes of total country samples
*******************************
preserve
* weighted age average
gen mAge_w = . 
foreach num of numlist 11/25 {
	sum aage [aweight=aweight] if acountry==`num'
	if "`r(mean)'"!="" replace mAge_w = `r(mean)' if acountry==`num'
}
format mAge_w %9.2f

gen intd = ym(ayear,amonth)
by acountry, sort: egen fields = min(intd)
by acountry, sort: egen fielde = max(intd)
format %tm fields fielde
gen n = 1
collapse (sum) n (max) fields fielde mAge_w, by(acountry)
log using ${logdir}/totalsamplesize_GGS.smcl, replace
li acountry fields fielde n mAge_w, noobs clean
log close
restore

******************
* Drop cases from Italy and Netherlands from the GGS data
******************
* drop Netherlands from GGS since no lifecourse data (e.g. date of retirement, first marriage etc.) is available
drop if acountry==18
* drop Italy from GGS since sample is too young compared to the others (max age of 64)
drop if acountry==17

**************
* generate important variables
**************
* gen a sample indicator
gen sample = child16plus==1 // 1 if there is a child of age 16 or older

* year of birth
gen birthy = abyear

* age
gen age = aage

* Recoding current activity
lab def a870 1501 "in apprenticeship or paid training" ///
			 1201 "working pensioner", modify
// Italy: recode employed/self-employed
replace a870 = 1 if a870==1701 & acountry==17

* Birth year of youngest child
gen ycbirth = chbyr1 
foreach num of numlist 1/20 {
	capt confirm variable chnum`num'
	if _rc == 0 {
		replace ycbirth = chbyr`num' if chnum`num'<. & chbyr`num' > ycbirth & chbyr`num'<. 
	}
}

* Birth year of oldest child
capt drop ocbirth
gen ocbirth = chbyr1 
foreach num of numlist 1/20 {
	capt confirm variable chnum`num'
	if _rc == 0 {
		replace ocbirth = chbyr`num' if chnum`num'<. & chbyr`num' < ocbirth & chbyr`num'<. 
	}
}
* Number of children
egen nofchildren = rownonmiss(chnum*)

* first child born
gen ttfchild = ocbirth - birthy
replace ttfchild = .d if ttfchild < 0
gen fchild = ocbirth <= ayear 
replace ttfchild = age if fchild==0 


* transition to non-active parenthood
* (= j¸ngestes Kind ist 16)
gen ynap = ycbirth + 16 
gen ttnap = ynap - birthy
// remove zero ages
replace ttnap = .d if ttnap < 0

gen nap = ynap <= ayear 
replace ttnap = age if nap==0 

/*
* retirement
// everpaid: currently working or job before activity or retired
gen everpaid = inlist(a870,1,2,1201) | a873==1 if a870 < . | a870==5
gen permsick = a870==7 if a870 < .
* transition to Retirement (at risk: everpaid==1 & permsick==0)
gen ageret = a871y - birthy if a870==5
// remove zero ages
replace ageret = .d if ageret < 0
gen ttret = ageret if everpaid==1 & permsick==0
gen ret = ageret < . if everpaid==1 & permsick==0 & !inlist(a871y,.d,.c) // important: do not treat refusals/dkn's as censored
replace ttret = age if ret==0 & everpaid==1 & permsick==0
*/


* First marriage
rename mar cmar
rename maryr cmaryr

gen mar = cmar
gen marfirstyr = cmaryr

foreach num of numlist 1/5 {
	capt confirm variable marnum`num' 
	if _rc==0 {
		replace mar = 1 if mar==0 & marnum`num'<.
		replace marfirstyr = maryr`num' if mar==1 & maryr`num'<. & maryr`num'< marfirstyr
	}
}
gen agefirstmar = marfirstyr - birthy if mar==1
// remove inplausible values 
replace agefirstmar = .d if agefirstmar < 0
gen ttfirstmar = agefirstmar 
replace ttfirstmar = age if mar==0

* Test: maryr1 contains always first marriage
assert maryr1 <= maryr2 if !mi(maryr1) & !mi(maryr2)
assert maryr2 <= maryr3 if !mi(maryr2) & !mi(maryr3)
assert maryr3 <= maryr4 if !mi(maryr3) & !mi(maryr4)
assert maryr4 <= maryr5 if !mi(maryr4) & !mi(maryr5)
* First marriage ended and how
* find first dissolution event 
gen marend = 0 if mar==1 
replace marend = 1 if mardiv1==1 | marsepreason1==1 & mar==1 // divorced or broke up
gen ttmarend = . if mar==1
replace ttmarend = marsepyr1 - birthy if marsepreason1==1 & mar==1 // date of break up
replace ttmarend = marsepyr1 if inlist(marsepyr1,.a,.b,.c) & marsepreason1==1 & mar==1 // date of break up
* override by date of divorce if available
replace ttmarend = mardivyr1 - birthy if mardiv1==1 & (!mi(ttmarend) & !mi(mardivyr1))  
* partner died ...
replace marend = 2 if marsepreason1==2 & mar==1
replace ttmarend = marsepyr1 - birthy if marend==2 & mar==1
replace ttmarend = marsepyr1 if inlist(marsepyr1,.a,.b,.c) & marend==2 & mar==1
replace ttmarend= age if marend==0

lab def marend 0 "censored" 1 "divorve/break-up" 2 "partner died", modify
lab val marend marend
tab ttmarend marend , miss
 
* Death of mothers and fathers
/*
a510
a511 => . she is alive/I do not know whether she still is alive /  I do not know anything about my biological mother
		, .a she is dead, but we do not know when she died 
a530 => same for biolog. father
a531 
*/
assert inlist(a510,1,2,3,4,.a,.b,.c)
assert inlist(a530,1,2,3,4,.a,.b,.c)

* Mothers
* Note: not available for Italy (coded -54)
gen deathmoth = a510==2 if inlist(a510,1,2) & a511!=-54 // do not code don't knows etc as censored
gen ttdeathmoth = a511 - birthy if deathmoth==1
replace ttdeathmoth = a511 if inlist(a511,.a,.b,.c)
* recode to non-negative durations
replace ttdeathmoth = .d if ttdeathmoth<0

* Fathers
* Note: not available for Italy (coded -54)
gen deathfath = a530==2 if inlist(a530,1,2) & a531!=-54 // do not code don't knows etc as censored
gen ttdeathfath = a531 - birthy if deathfath==1
replace ttdeathfath = a531 if inlist(a531,.a,.b,.c)
* recode to non-negative durations
replace ttdeathfath = .d if ttdeathfath<0

* ttdeath1p
gen death1p = max(deathfath,deathmoth) if !mi(deathfath) & !mi(deathmoth) & ttdeathfath<.a & ttdeathmoth<.a
gen ttdeath1p = min(ttdeathfath,ttdeathmoth) if death1p==1 & !mi(deathfath) & !mi(deathmoth) & ttdeathfath<.a & ttdeathmoth<.a
gen death2p = (deathfath==1 & deathmoth==1) if !mi(deathfath) & !mi(deathmoth) & ttdeathfath<.a & ttdeathmoth<.a
gen ttdeath2p = max(ttdeathfath,ttdeathmoth) if !mi(deathfath) & !mi(deathmoth) &  death2p==1 & ttdeathfath<.a & ttdeathmoth<.a

* Both parents dead
gen deathboth = death1p==1 & death2p==1 if !mi(deathfath) & !mi(deathmoth) & ttdeathfath<.a & ttdeathmoth<.a
gen ttdeathboth = max(ttdeath1p, ttdeath2p) if deathboth==1

* checks
assert death1p==1 if death2p==1
assert death2p==0 if death1p==0
assert ttdeath1p <= ttdeath2p if !mi(ttdeath1p) & !mi(ttdeath2p)
assert death1p==1 & death2p==1 if deathboth==1

* right censor cases
replace ttdeathfath = age if deathfath==0
replace ttdeathmoth = age if deathmoth==0
replace ttdeath1p = age if death1p==0
replace ttdeath2p = age if death2p==0
replace ttdeathboth = age if deathboth==0

* leaving home
egen notemptynest = anymatch(chresident*), value(1)
gen leavehome = notemptynest==0 
gen ttleavehome = age if notemptynest==1
replace ttleavehome = lastleave - birthy if notemptynest == 0
// check for deaths, if ttleavehome ==. & notemptynest==0
// take last death
gen lastdeath = 0
foreach num of numlist 1/20 {
	capt confirm variable chdeathyr`num'
	if _rc > 0 continue
	replace lastdeath = chdeathyr`num' if chdeathyr`num' > lastdeath & /// 
										  !mi(chdeathyr`num') 
}
replace lastdeath = . if lastdeath==0
* replace
replace ttleavehome = lastdeath - birthy if notemptynest == 0 & ttleavehome==.
drop lastdeath
drop notemptynest


* Interview year
gen inty = ayear

* Model transition
replace gphyr = ayear if grandc==0 & sample==1 // set to interview time if no event

* Weighted analysis
stset gphyr if sample==1 [iweight=aweight], origin(abyear) f(grandc) 


* Mark different steps of sample selection (see above)
* 1st selection
gen sampleSelect1 = (child16plus==1)  & man < . 
* 2nd selection
gen sampleSelect2 = sampleSelect1 & inrange(age, ${lowerAgeLimit}, ${upperAgeLimit}) 
* 3rd selection
gen sampleSelect3 = sampleSelect2 &  (_st==1) & !(_t < 20 & _d==1)	// the latter term throws out highly inplausible grandparenthood ages below age 20

* check
fre acountry
fre acountry if sampleSelect1==1
fre acountry if sampleSelect2==1
fre acountry if sampleSelect3==1
* events
fre acountry if sampleSelect3==1 & _d==1

keep arid acountry aweight inty* man age EDU birthy _*  tt* mar nap ret fchild ISCED* death* leavehome marend everpaid nofchildren sampleSelect*

gen GGS = 1

// save ${prepared}\pooleddata, replace
save ${prepared}/prepared_ggs, replace

clear
exit
