/*

Replication files 

Leopold, T., & Skopek, J. (2015). The Demography of Grandparenthood: An International Profile. Social Forces, 94(2), 801–832. https://doi.org/10.1093/sf/sov066

Data Preparation for National Survey of Families and Households (NSFH).

*/

/*
 Preparation of NSFH Data ()
 (wave 3 + wave 1&2)
*/

/*************************
# Wave 1
The national (USA) sample of 13,007 includes a 
main cross-section of 9,637 households plus an 
oversampling of blacks, Puerto Ricans, Mexican Americans, 
single-parent families, families with step-children, 
cohabiting couples and recently married persons. 
One adult per household was randomly selected as the 
primary respondent. Several portions of the main interview 
were self-administered to facilitate the collection of 
sensitive information as well as to ease the flow of 
the interview. The average interview lasted one hour 
and forty minutes. In addition, a shorter self-administered 
questionnaire was given to the spouse or cohabiting 
partner of the primary respondent. A considerable amount 
of life-history information was collected, including: 
the respondent's family living arrangements in childhood, 
departures and returns to the parental home, and histories 
of marriage, cohabitation, education, fertility, and employment. 

The design permits the detailed description of past and current 
living arrangements and other characteristics and experiences, 
as well as the analysis of the consequences of earlier patterns 
on current states, marital and parenting relationships, kin contact, 
and economic and psychological well-being. 

This study has been undertaken explicitly to provide a data 
resource for the research community at large and was designed 
with advice from a large number of consultants and correspondents. 
The substantive coverage has been kept broad to permit the 
holistic analysis of family experience from an array of 
theoretical perspectives. 

More detailed information on Wave 1 content and on 
the two subsequent waves (Wave 2: 1992-94, Wave 3: 2002-04) 
is available on the NSFH website, http://www.ssc.wisc.edu/nsfh.

Sampling Procedure
The main sample for the National Survey of 
Families and Households is a national, multi-stage area probability 
sample containing about 17,000 housing units drawn from 100 
sampling areas in the conterminous United States. 
For details on the sample design of NSFH, Wave 1, see 
National Survry of Families and Housholds: a Sampling Report 
at ftp://elaine.ssc.wisc.edu/pub/nsfh/c1app_l.001

Mode of Data Collection
face-to-face interviews and self-administered questionnaires


# Wave 3
Because of funding constraints, this sample does not 
include respondents under age 45 as of January 2000 (or their spouses) 
if they did not have a wave 1 focal child eligible for interview at wave 2.

see field report of wave3!

Main respondents:

1) NSFH1 main respondents who had a 
   focal child eligible for an NSFH3 interview.  
   Focal child eligible for wave 3 were those who 
   had been eligible for wave 2.  These young adults 
   were ages 18-34 at wave 3, 10-24 at wave 2, and 
   5-18 at wave 1. 

2) NSFH1 main respondents who were ages 45 and 
   older by January 1, 2001—in mid and later life.  
   Thus, the wave 3 sample does not include NSFH1 
   respondents who were under age 45 if they did 
   not have an eligible focal child.  

NSFH1 Spouse/partners:

For both samples, if the selected main respondent had a 
spouse or partner at time1, that spouse or partner was 
also selected for a time 3 interview.  The wave 3 sample 
did not include new spouses or partners at either NSFH2 
or NSFH3.  

Proxy Interviews

A proxy interview was attempted when a main respondent was 
deceased or too ill to be interviewed at time 3, unless they 
had an NSFH1 spouse/partner.  If there was to be an interview 
with a spouse/partner, this interview would cover the proxy 
questions about the main respondents’ death or illness as 
part of a more extensive series on this topic.

There were two exceptions.  Proxy interviews were sought if 
the NSFH1 spouse/partner was deceased or too ill to be 
interviewed, or if the couple was not together at time 2.  
A proxy was needed in the latter case because the NSFH3 spouse 
interview asked about experiences since wave 2, and hence any 
questions on spousal death or illness would not be about the 
main respondent.  Proxy interviews for main respondents were 
not sought in the event that a surviving spouse/partner refused 
the wave 3 interview or could otherwise not be interviewed.  
Proxy interviews were only required for main respondents; no 
proxy was sought for deceased or too ill spouse/partners or 
focal children.

Roster Data in Main Respondent/Spouse Interviews

In the interview with the main respondents and spouses there were 
three “rosters”.

•	Roster 1   Questions about each member of the respondent’s household
•	Roster 2   Questions about each of the respondent’s sons and 
			   daughters (of any age) who were living elsewhere
•	Roster 3   Questions about each of the respondent’s current (!) spouse or 
			   partner’s sons or daughters  who were living elsewhere

This file contains household roster data for main respondents and spouses 
interviewed at NSFH3.  A series of questions was asked about each person 
in the respondent's household.   

Only a small subset of questions were asked regarding the respondent 
him/herself. There are 31 variables for each household member other 
than the respondent; three variables for the respondent.  
The respondent is always the first entity in the roster.  

Data from each of these rosters are included in separate files, 
concatenated in fixed format.  For a detailed list of variables 
included in this file, see the roster codebook.

Status file

This file (with a data file currently only available in text format) 
shows which interview type is available for which cases, and it shows 
the result code for cases that were not interviewed.  Among other uses, 
this file permits the analysis of response rates. 

Union Files Description
!Note!: Third interview respondents who were cohabiting at the time of 
the second interview have been deleted from the unionhist.sav and 
marhist.sav files.  These cases were inadvertently skipped around 
the sequence asking about the outcome of their union at NSFH2.  
As a consequence of the sample constraints discussed above, the omitted 
cohabiting cases are a select subset of all respondents who were 
cohabiting at the second interview, and they represent only 5.6 percent 
of the respondents at the third wave who have ever been in a union.

The files for main respondents combine the information on cohabitation 
and marriage histories that was reported at each of the three interviews.  
The first interview asked about the respondent’s experience up until the 
date of interview; the second interview asked about experience between 
interviews 1 and 2; and the third interview asked about the time since 
wave 2.  (The only exception is that respondents at wave 3 who were 
not interviewed at wave 2 were asked about their histories since the 
first interview.) These histories have been organized into two files for 
the main respondent: a union file including both cohabitations and 
marriages, and a marriage history file.  The integration of reports 
across interviews is very complex and frequently required inferences 
on the basis of related information.  

In the union history file, all unions are ordered sequentially, whether 
begun by marriage or cohabitation, and whether or not a marriage occurred. 
For each union, variables describe how a union began (howbeg01) or ended 
(howend01), whether or not a cohabitation resulted in marriage (cohmar, 
mardat), and the dates associated with each transition (begdat, enddat).  

The marriage history file includes only marriages.  As in the file above, 
if a respondent married a cohabiting partner, the beginning date of the 
union is the date they started living together. The variables for each 
marriage in this file are the same as those in the union history file with 
one exception: there is an additional variable that identifies the parity 
of the respondent’s union at the time of each marriage.  For example, if 
two cohabitations ended without marriage, and the third union was a marriage, 
this variable codes the marriage as the third union. 

  

**********************************************************/

/*************************
Preparation of the Sample

* Sample Selection strategy
- select only main respondents and spouses from main sample (excluding oversample)
- select respondents/spouses of common age range at time of w3 interview
- no proxy interviews 

* Grandparenting 
merge Grandparenting variables of wave3 and wave2 of the wave3 sample. 
necessary? 

* Children (wave 3, Roster): 
Main Respondents and NSFH1 spouses were asked a series of 
questions about each son and daughter of any age not 
currently living in their household.   

see HHMEM_CODEBOOK_04052005.doc!
see sons-daughts living elsewhere 04072005.doc!

Roster 1   Questions about each member of the respondent’s household
Roster 2   Questions about each of the respondent’s sons and daughters (of any age) who were living elsewhere
Roster 3   Questions about each of the respondent’s current spouse or partner’s sons or daughters  who were living elsewhere

* Leaving home
=> has to be modeled over waves since wave 3 asks
RD16MP             month r and ch began live apart

In what month and year after (previous interview) did you and
(child) first begin living apart for three months or longer?
  (The Q name was 'k23'.)
WAVE 1

Household Composition (MCASEID-M44)
Detailed household composition | Children living in household | Disability or Chronic Illness; care and assistance given and received

Biological children under age 19 living elsewhere (M411-M443C) Select One Focal Child   
When last lived with R | Current residence | Information on other parent regarding residence, marital status, 
other children | R's contact with child | Conflict over child | Legal agreements regarding residence, visits, 
child support, alimony | Child support payments

Children/step-children age 19 or older in household OR children/step-children of any age away from home attending 
college (M455NUM-M471E) Select one focal child   
School attendance | Financial aid | R's contribution toward schooling expenses | Child's living arrangements | 
Child's employment and earnings | Child's payments to R for room or board | R's payments of child's expenses

All biological and stepchildren over age 19 not away at school, but living elsewhere (M473-M482P10) 
Children's age, marital status, own children | Current residence | R's contact with children

* Entry into first job

Wave 1 
Employment (M528-M591C) 
Employment history | Current occupation, hours, earnings | Current second job | 
Current work schedule |Travel to work and away from home | Childcare arrangements while at work | 
Work experience in 1986 | Occupation at age 50

M529 Q.529   Did R ever work for pay?
M529T01M 	 cent month first job 

Wave 2
MO7
MO10T1M-MO10T4M

        In what month and year did you start working for 
        (the first time/two months or longer) after NSFH1?
		
RO7 working since last intrvw
In (last interview date), you were not working for pay.  Since
then have you worked in a full- or part-time job for two months or
longer?

RO10T1M            mo started first job after last intrvw

In what month and year did you start working for the first time
after (last interview date)?
stop

RO10T1Y            yr started first job after last intrvw
		
* Entry into retirement
Wave 3
RT1811             consider self retired

We are interested in what people think about retirement, whether they
themselves are completely retired or not.  At this time do you
consider yourself partly retired, completely retired, or not retired
at all?

  (The Q name was 'se18q11'.)

            %   Freq  VALUE  
         17.0    390      1  PARTLY RETIRED
         50.8  1,167      2  COMPLETELY RETIRED
         32.2    740      3  NOT RETIRED AT ALL
                  30     -2  REFUSED
                   2     -1  DON'T KNOW
               4,948      .  (No Data)
        -----  -----
        100.0  7,277 cases
RT1811B            change job/reduce hrs for part retirem

In connection with your partial retirement, did you change your job,
reduce your work hours, or do something else?

  (The Q name was 'se18q11b'.)

            %   Freq  VALUE  
         20.9     80      1  CHANGED JOB
         38.7    148      2  REDUCED WORK HOURS
          9.4     36      3  CHANGED JOB AND REDUCED WORK HOURS
         30.9    118      4  OTHER
                   1     -2  REFUSED
                   7     -1  DON'T KNOW
               6,887      .  (No Data)
        -----  -----
        100.0  7,277 cases
		
RT1812Y            year retired

(INTERVIEWER: ENTER YEAR 1937-2004)

  (The Q name was 'se18q12y'.)

        7,277 cases (Range of valid codes: 1,944-2,002)
		
**************************/

set more off
run init.do 



/*******************************
* PREPARE relevant Wave 1 Data 
 - extract SAMPLE marker (for removing oversample later)
 - extract weights (individual case weights)
 - extract other relevant variables (e.g. educational level; children information etc.)
 - generate basic variables
***********************************************************/
tempfile w1
use ${NSFH_wave1}, clear

* date of birth
mvdecode M485M, mv(9997/9998=.a)
gen tbirth = M485M-(12*(1960-1900)+1)
format tbirth %tm

gen birthyr = year(dofm(tbirth))

* R has biological/adopted children
egen children = anymatch(K1 K2 K4 K8 K10 K12), val(1)

* Variables for weighting 
gen married = inlist(MARCOHAB,1,2) 
recode COMPLED (0/11 99=1 "low") (12=2 "middle") (13/20=3 "high"), gen(edu)
mvdecode IREARN, mv(9999997/9999999=.a)
gen REARN = IREARN
replace REARN = 0 if mi(IREARN)
gen REARN_MISS =  mi(IREARN)


* Take COMPLED/EDUCAT as proxy for highest education (neglect education upgrades reported in W2&3)
* (COMPLED => completed education, see VARIABLES_c1app_k.001.txt as doc)
keep MCASEID M2BP01 E1318 E1310 E1301 E1308 birthyr children REGION METRO REARN REARN_MISS married edu MARCOHAB HHTYPE IREARN SAMPLE SAMWT SWT IWT PADJ WEIGHT M2DP01 EDUCAT COMPLED MYEAR MMONTH M528 M529 M529T01M
renvars *, prefix(W1)

save `w1', replace

/**********************************************
* Prepare Data from Wave 2
- extract relevant variables (e.g. death of parents)
**********************************************/
use ${NSFH_wave2main}, clear

* Job after NSFH W1, mother & father alive, yr of death
keep MCASEID MO7 MO10T1M MT1811 MT1812Y MF6 MF4 MF1 MF3
tempfile w2
renvars *, prefix(W2)
save `w2', replace


/**********************************************
* Prepare Wave 3 status file 
 (needed for generating wave 3 weights later on)
***********************************************/
tempfile status
use ${NSFH_wave3}/statusfile_010307, clear
rename caseid casenum
renvars whofieldw3-f3decill, prefix(ST_)
save `status' , replace


************************************************
* Prepare Marriage Data
* 1) take harmonized marriage data from an extra file of wave 3 
* 2) reconstruct first time marriage & dissolution
*    for residual cases from wave 1
************************************************
/******* Marriage Data **********

Get date of first marriage and information 
on whether an how it ended (for main respondents first)

-> For Respondents check marriage history file
-> note: respondents cohabitating at W2 are not included in 
         this file due to an interview error. Lookup w2 & w1 for those. 

*********************************/
* use marriage history file
use ${NSFH_wave3}/marhist111605, clear
mvdecode mardat* sepdat* divdat* begdat* enddat* widdat*, mv(9996/9999=.a)

keep case nummar mardat* sepdat* divdat* begdat* enddat* widdat* howend*

reshape long mardat0 sepdat0 divdat0 begdat0 enddat0 widdat0 howend0, i(case) j(n)
drop if n > nummar

* mark cases with undefined date of first marriage
gen undefined = mardat0==.a & nummar==1
by case (n), sort: replace undefined = undefined[_n-1] if _n>1

* keep only first marriages
by case (mardat0), sort: keep if _n==1

gen mar = 1

* convert century months into stata time
gen tmar = mardat0 - (12*(1960-1900)+1)
replace tmar = .a if mardat0==.a

format tmar %tm
drop mardat0
* gen marend
recode howend0 (2/3 = 1 "divorve/break-up") (4=2 "partner died") (8=0 "censored") (9=.a), gen(marend)
* take sepdat if div and divdat is empty
replace enddat0 = sepdat0 if divdat0==.a & !mi(sepdat0) & howend0==3
gen tmarend = enddat0 - (12*(1960-1900)+1) if enddat0 > 0
replace tmarend = .a if enddat0==.a
format tmarend %tm


isid case
rename case casenum
keep casenum mar tmar tmarend marend

tempfile firstmar
save `firstmar'

/******************************
* Marriage history in Wave 1 for main respondents
*******************************/
use ${NSFH_wave1}, clear

keep MCASEID M95-M163

mvdecode M95, mv(99=.a)
mvdecode M96M M100M M101M M102M, mv(9996=. \9998/9999=.a)

* first marriage (mar=1 if yes, tmar date of first marriage in stata time) 
gen mar = M95 > 0 if !mi(M95)
gen tmar = M96M - (12*(1960-1900)+1)
replace tmar = .a if M96M==.a
format tmar %tm

* gen marend
recode M99 (1/2 = 1 "divorve/break-up") /// 
		   (3=2 "partner died") (6=0 "censored") (9=.a) /// 
		   if mar==1, gen(marend)
gen tmarend = min(M100M, M101M, M102M) - (12*(1960-1900)+1) if marend > 0 & !mi(marend)
replace tmarend = .a if (M100M==.a | M101M==.a | M102M==.a) & mi(tmarend) & marend > 0 & !mi(marend)
 
format tmarend %tm

keep MCASEID mar tmar marend tmarend
* Rename variables
renvars *, prefix(W1)

tempfile w1marriage
save `w1marriage' 

 
/*****************************************
*
* Children data: use rosters from wave 3
*
*****************************************/
/*
Year born child 
rj5p0?y  -> child 1-6
=> ACHTUNG: bezieht sich auf Zeit seit letztem Interview

Month & Year of interview
idatyy 
idatmm

rh9  how many grandchildren
rh10 age of youngest grandchild
rh11 age of oldest grandchild


Roster Data in Main Respondent/Spouse Interviews

In the interview with the main respondents and spouses there were three “rosters”.

Roster 1   Questions about each member of the respondent’s household
Roster 2   Questions about each of the respondent’s sons and daughters (of any age) who were living elsewhere
Roster 3   Questions about each of the respondent’s current spouse or partner’s sons or daughters  who were living elsewhere

Dokumentation: see sons-daughts living elsewhere 04072005.doc!

This file contains household roster data for main respondents and spouses interviewed at NSFH3.  A series of questions was asked about each person in the respondent's household.   

Only a small subset of questions were asked regarding the respondent him/herself.
There are 31 variables for each household member other than the respondent; three variables for the respondent.  The respondent is always the first entity in the roster.  Data from each of these rosters are included in separate files, concatenated in fixed format.  For a detailed list of variables included in this file, see the roster codebook.

*/

* Roster
use ${NSFH_wave3}/hhmem_c04042005main, clear

* Main Respondent data
tempfile mainresp
keep caseid sex_a ms_a pnum_a hhpn_a
save `mainresp'

* Children
* Roster 1 (members of household)
tempfile hh
use ${NSFH_wave3}/hhmem_c04042005main, clear

drop *_a
keep caseid rel_? fpn_? age_? 

reshape long rel_ fpn_ age_ , i(caseid) j(j) string
drop if mi(age_) & mi(rel_) & mi(fpn_)

* Select only biological children
keep if rel_==3
drop rel_

rename  fpn_ chfpn
rename  age_ chage
gen chhh = 1

drop j

save `hh'

* Roster 2 (children elsewhere)
use "${NSFH_wave3}/roster2 09212005-mainR.dta", clear

// Question? is there a way to distinguish between biolog. and non-biolog children?
// no! neglect this issue.
* Variables: 
* age2_* 	AGE
* fpn2_* 	PERSON NUMBER           
* RD16MP    month r and child began live apart                                          
* RD16YP    yr r and child began live apart                                         
                                              
keep caseid age2_? fpn2_? 

reshape long fpn2_ age2_, i(caseid) j(j) string
drop if mi(fpn2_) & mi(age2_)

drop j
rename  fpn2_ chfpn
rename  age2_ chage
gen chhh = 0

append using `hh'

recode chage (-1=.a)

* order oldest child first
gsort +caseid -chage, gen(sortid)
by caseid (sortid), sort: gen chnum = _n

drop sortid 
order caseid chnum chage chfpn

gen n = chnum
reshape wide chnum chage chfpn chhh, i(caseid) j(n)

tempfile childR
save `childR'

* integrate
* Basic data
use `mainresp'
// append using `spouse'
isid caseid

tempfile sex
save `sex'

* childdata
use `childR', clear
// append using `childS'
tempfile child
save `child'

/***********************
* Prepare data from WAVE 3
***********************/

* Main respondent
use ${NSFH_wave3}/main05022005, clear // N=7277 (main resp. + spouses)
* Keep only main respondent data
keep if type=="R" // N=4600

merge 1:1 caseid using `sex', assert(matched using) keep(matched) nogen
merge 1:1 caseid using `child', assert(master matched using) keep(master matched) nogen
merge 1:1 casenum using `firstmar', assert(master matched) nogen

* Merge W1 Data
destring case, gen(W1MCASEID)

merge 1:1 W1MCASEID using `w1', assert(matched using) keep(matched) nogen 
merge 1:1 W1MCASEID using `w1marriage', assert(matched using) keep(matched) nogen 

* Merge W2 Data
gen W2MCASEID = W1MCASEID
merge 1:1 W2MCASEID using `w2', assert(master matched using) keep(master matched) nogen 

* Merge Statusfile data
merge n:1 casenum using `status', assert(matched using) keep(matched) nogen force

* N=4600
count 

* year of birth (birthy)
mvdecode doby, mv(-2=.b)
gen birthyr = 1900+doby
* fill up missing birth years with data from wave 1
replace birthyr = W1birthyr if birthyr==.

clonevar sex = sex_a
gen age = idatyy - birthyr

gen man = sex==1
gen usa = 1

* Sample selection variable: One biological child age 16 or older
gen child16plus = 0
foreach var of varlist chage* {
	replace child16plus = 1 if `var'>=16 & !mi(`var')
}

* Number of children
egen nofchildren = rownonmiss(chnum*)

* Sample indicator
* keep only main sample in analytical sample (remove oversample which is idendified by W1SAMPLE=2)
* main sample: N=3554 
gen sample = child16plus==1 & W1SAMPLE==1 & inrange(age,${lowerAgeLimit},${upperAgeLimit})

* Weights
* (take individual case weight)
* Calculate weights correcting for panel drop out
preserve 
	keep if sample == 1
	* Additional Sample selection to the lower and upper age limit (e.g. 65+)
	keep if age >= ${lowerAgeLimit}
	* Upper bond 
	keep if age <=${upperAgeLimit}
	keep casenum
	tempfile samplew3
	save `samplew3'
restore 
preserve 
use `status', clear
gen W1MCASEID = casenum
merge 1:1 W1MCASEID using `w1', assert(matched) nogen
merge 1:1 casenum using `samplew3', assert(master matched)
gen samplew3 = _merge==3
* restrict to main sample, people with children and birth cohorts
keep if W1SAMPLE == 1 
// * Birthcohort from 1921-1938 (according to age selection)
// keep if inrange(W1birthyr, 1921,1938)
local from = 2001-${upperAgeLimit}
local to = 2003-${lowerAgeLimit}
keep if inrange(W1birthyr, `from',`to') 
keep if W1children==1 | samplew3==1
rename W1birthyr birthyr
log using ${logdir}/weighting_model_W3NSFH.smcl, replace
* Logit model for estimating participation probability in sample of W3
* birth year (categorical)
* sex 
* married 
* education (low, middle, high)
* earnings 
* metropolitan status
* region of United States
logit samplew3 i.birthyr i.W1M2DP01 i.W1married i.W1edu c.W1REARN i.W1METRO i.W1REGION
est table, b(%9.3f) star
log close
est store probw3
predict probw3
restore

* predict probability of inclusion to sample w3
predict probw3 if sample==1


* Weights
* dweight_a => individual case weight from w1
gen dweight_a = W1WEIGHT
* dweight_b => individual case weight from w1 + inv. prob. of part. in w3
gen dweight_b = dweight_a * (1/probw3)

* Default weight: w3 non-response adjusted individual case weight
gen dweight = dweight_b

*********************
* TRANSITIONS
*********************

* DEATH OF PARENTS
capt drop deathmoth tdeathmoth deathfath tdeathfath

* wave 1
mvdecode W1E1301 W1E1310 , mv(7/9=.a)
mvdecode W1E1308 W1E1318, mv(97/99=.a \ 96=.)
replace W1E1308 = 1900 + W1E1308 
replace W1E1318 = 1900 + W1E1318
* wave 2
mvdecode W2MF1 W2MF4 , mv(8/9=.a)
mvdecode W2MF3 W2MF6 , mv(98/99=.a)
replace W2MF3 = 1900 + W2MF3
replace W2MF6 = 1900 + W2MF6
* wave 3
mvdecode rf1 rf4 rf3 rf6, mv(-2/-1=.a)

* Fill up information on death of mother wave by wave
* Death of mother (W1)
gen deathmoth = W1E1301 == 2 if !mi(W1E1301)
gen tdeathmoth = W1E1308 if deathmoth==1
* Death of mother (W2)
replace deathmoth = W2MF1==2 if !mi(W2MF1) & deathmoth!=1
replace tdeathmoth = W2MF3 if !mi(W2MF3) & mi(tdeathmoth)
* Death of mother (W3)
replace deathmoth = rf1==2 if !mi(rf1) & deathmoth!=1
replace tdeathmoth = rf3 if !mi(rf3) & mi(tdeathmoth)

* Fill up information on death of father wave by wave
* Death of father (W1)
gen deathfath = W1E1310 == 2 if !mi(W1E1310)
gen tdeathfath = W1E1318 if deathfath==1
* Death of father (W2)
replace deathfath = W2MF4==2 if !mi(W2MF4) & deathfath!=1
replace tdeathfath = W2MF6 if !mi(W2MF6) & mi(tdeathfath)
* Death of mother (W3)
replace deathfath = rf4==2 if !mi(rf4) & deathfath!=1
replace tdeathfath = rf6 if !mi(rf6) & mi(tdeathfath)

* transitions variables: death of parents
* death of parents
gen ttdeathmoth = tdeathmoth - birthyr if deathmoth==1
replace ttdeathmoth = .a if tdeathmoth==.a

gen ttdeathfath = tdeathfath - birthyr if deathfath==1
replace ttdeathfath = .a if tdeathfath==.a

* recode to non-negative durations
replace ttdeathmoth = .d if ttdeathmoth<0
replace ttdeathfath = .d if ttdeathfath<0

* ttdeath1p
gen death1p = max(deathfath,deathmoth) if !mi(deathfath) & !mi(deathmoth) & ttdeathfath<.a & ttdeathmoth<.a
gen ttdeath1p = min(ttdeathfath,ttdeathmoth) if death1p==1 & !mi(deathfath) & !mi(deathmoth) & ttdeathfath<.a & ttdeathmoth<.a
gen death2p = (deathfath==1 & deathmoth==1) if !mi(deathfath) & !mi(deathmoth) & ttdeathfath<.a & ttdeathmoth<.a
gen ttdeath2p = max(ttdeathfath,ttdeathmoth) if !mi(deathfath) & !mi(deathmoth) &  death2p==1 & ttdeathfath<.a & ttdeathmoth<.a

* Both parents dead
gen deathboth = death1p==1 & death2p==1 if !mi(deathfath) & !mi(deathmoth) & ttdeathfath<.a & ttdeathmoth<.a
gen ttdeathboth = max(ttdeath1p, ttdeath2p) if deathboth==1

* checks
assert death1p==1 if death2p==1
assert death2p==0 if death1p==0
assert ttdeath1p <= ttdeath2p if !mi(ttdeath1p) & !mi(ttdeath2p)
assert death1p==1 & death2p==1 if deathboth==1

* right censoring of cases
replace ttdeathfath = idatyy - birthyr if deathfath==0
replace ttdeathmoth = idatyy - birthyr if deathmoth==0
replace ttdeath1p = idatyy - birthyr if death1p==0
replace ttdeath2p = idatyy - birthyr if death2p==0
replace ttdeathboth = idatyy - birthyr if deathboth==0

* FIRST MARRIAGE 
* Transition variables: marriage (mar/ttmar) 
* replace first wave data for those not having a marriage record in wave 3
gen marprob = mar==. & W1mar==1
replace mar = 1 if W1mar==1 & mar==. 
replace tmar = W1tmar if marprob==1 & mar==1
replace marend = W1marend if marprob==1
replace tmarend = W1tmarend if marprob==1
replace mar = 0 if mar==.
gen ttmar = year(dofm(tmar)) - birthyr if tmar < . & mar==1
replace ttmar = .a if tmar==.a
replace ttmar = idatyy - birthyr if mar==0
drop tmar 

rename ttmar ttfirstmar

* Transition variables: dissolution of first marriage
gen ttmarend = year(dofm(tmarend)) - birthyr if tmarend < . & mar==1 & marend > 0 & !mi(marend)
replace ttmarend = idatyy - birthyr if mar==1 & marend==0
* right censor prob cases at date of wave 1 (since we have no further information)
replace ttmarend = (1900+W1MYEAR) - birthyr if mar==1 & marend==0 & marprob==1
replace ttmarend = .a if tmarend == .a

* GRANDPARENTHOOD
* grandparents
mvdecode rh9 rh10 rh11, mv(-1=.a\-2=.b)
gen grandc = rh9>0 & !mi(rh9)

fre grandc
fre rh10 rh11 if grandc==0
* age of oldest grandchild
gen ageogc = rh11 if grandc==1

gen gphyr = idatyy - ageogc if grandc==1
replace gphyr = idatyy if grandc==0 // set to interview time if no event

* FIRST JOB
* Transition variables: first job
gen everpaid = inlist(W1M529,2,3) if inlist(W1M529,1,2,3) // Armed forces/Ever work
replace everpaid = 1 if inlist(W2MO7,1,6) & everpaid == 0 // if never paid in W1 look up whether working was reported in W2
replace everpaid = 1 if inlist(ro7,1,-7) & everpaid==0 // if never paid in W1 & W2 look up wheter working was reported in W3 

* year of entry into first job
mvdecode W1M529T01M, mv(9996=. \ 9998/9999=.a)
gen tfjob = W1M529T01M - (12*(1960-1900)+1)
replace tfjob = .a if W1M529T01M==.a
format tfjob %tm
* take time from W2 if never worked at W1 
mvdecode W2MO10T1M, mv(9999=. \ 9998=.a)
gen tfjob2 = W2MO10T1M - (12*(1960-1900)+1)
format tfjob2 %tm
replace tfjob = tfjob2 if mi(tfjob) & !mi(tfjob2) & inlist(W1M529,1,3,6) & W2MO7==1
* take time from W3 if never worked at W2 
mvdecode ro10t1y, mv(-1=.a)
gen tfjob3 = ym(ro10t1y, 6)
format tfjob3 %tm
replace tfjob = tfjob3 if mi(tfjob) & !mi(tfjob3) 
replace everpaid = 1 if tfjob < . & inlist(everpaid,0,.)
drop tfjob2 tfjob3
* duration variable
gen firstjob = everpaid==1 if !mi(everpaid)
gen ttfirstjob = year(dofm(tfjob)) - birthyr if tfjob < . & everpaid==1 
replace ttfirstjob = idatyy - birthyr if everpaid==0 
* cut inplausible durations
replace ttfirstjob = .d if ttfirstjob < 12 & firstjob==1

* RETIREMENT
* transition variables: retirement (year of retirement conditional on everpaid)
mvdecode rt1811 rt1812y, mv(-2/-1=.a)
* 3 states of self-considered  retirement: 1 partly 2 completely 3 not at all
* take as retired partly & completely
gen ret = inlist(rt1811,1,2) if !mi(rt1811) & everpaid==1
gen ttret = rt1812y - birthyr if ret==1
replace ttret = .a if rt1812y==.a
* many missings => look up in wave 2 data
mvdecode W2MT1811, mv(9=.)
mvdecode W2MT1812Y, mv(99=.)
gen ret2 = inlist(W2MT1811,1,2) if !mi(W2MT1811)
gen ttret2 = (1900+W2MT1812Y) - birthyr 
* favor wave 2 data
replace ret = 1 if ret2==1 & everpaid==1
replace ttret = ttret2 if mi(ttret) & !mi(ttret2) & everpaid==1

replace ret = 1 if ttret < . & everpaid==1

* right censor cases
replace ttret = idatyy - birthyr if ret==0 & everpaid==1

* check
tab ttret ret if sample==1 & everpaid==1
tab ttret ret if sample==1 & everpaid==1, miss




* DESCRIPTION OF THE ORIGIN WAVE 3 SAMPLE 
gen intd = ym(idatyy, idatmm)
format %tm intd
egen fields = min(intd)
egen fielde = max(intd)
format %tm field?

log using ${logdir}/totalsamplesize_NSFH.smcl, replace
count
li field? in 1
sum age
log close
drop intd fields fielde

* FIRST TIME PARENTHOOD
* Calc year of birth for children
foreach num of numlist 1/20 {
	capt confirm variable chnum`num'
	if _rc == 0 {
		gen chbyr`num' = idatyy - chage`num'
		order chbyr`num', after(chage`num')
	}
}

* Birth year of youngest child
gen ycbirth = chbyr1 
foreach num of numlist 1/20 {
	capt confirm variable chnum`num'
	if _rc == 0 {
		replace ycbirth = chbyr`num' if chnum`num'<. & chbyr`num' > ycbirth & chbyr`num'<. 
	}
}

* Birth year of oldest child
gen ocbirth = chbyr1 
foreach num of numlist 1/20 {
	capt confirm variable chnum`num'
	if _rc == 0 {
		replace ocbirth = chbyr`num' if chnum`num'<. & chbyr`num' < ocbirth & chbyr`num'<. 
	}
}

* first child born
gen ttfchild = ocbirth - birthyr
replace ttfchild = .d if ttfchild < 0
gen fchild = ocbirth <= idatyy 
replace ttfchild = age  if fchild==0 

* NON-ACTIVE PARENTING
* transition to non-active parenthood
* (= jüngestes Kind ist 16)
gen ynap = ycbirth + 16 
gen ttnap = ynap - birthyr
// remove zero ages
replace ttnap = .d if ttnap < 0
gen nap = ynap <= idatyy 
replace ttnap = age if nap==0 


* FINISH

egen intymin = min(idatyy)
egen intymax = max(idatyy)

rename idatyy inty

// 4,600
count

* drop oversample of blacks, puerto ricos, single families etc.!!
drop if W1SAMPLE == 2
* keep only main sample!

* // 3554
count

* generate st-Variables for transition to grandparenthood 
quiet: stset gphyr if sample==1 , origin(birthyr) f(grandc) 

rename birthyr birthy
drop _origin


* Mark different steps of sample selection (see above)
* 1st selection
gen sampleSelect1 = (child16plus==1) & man < . 
* 2nd selection
gen sampleSelect2 = sampleSelect1==1 & inrange(age, ${lowerAgeLimit}, ${upperAgeLimit})   
* 3rd selection
gen sampleSelect3 = sampleSelect2 &  ( _st==1) & !(_t < 20 & _d==1)	// 1 unplausiblen Fall löschen (ältestes kind 1995 geboren und 6 Enkelkinder)


count if sampleSelect1 == 1
count if sampleSelect2 == 1
count if sampleSelect3 == 1
count if sampleSelect3 == 1 & _d==1

gen NSFH = usa==1
gen EDU = W1edu

* keep relevant variables
keep case usa NSFH man EDU birthy _* inty*  gphyr birthy grandc age tt* fchild nap dweight* death* mar* firstjob everpaid ret nofchildren sampleSelect*

* save transition data
// save ${prepared}\transition_sample_nsfh, replace
	
save ${prepared}/prepared_nsfh, replace



