/*

Replication files 

Leopold, T., & Skopek, J. (2015). The Demography of Grandparenthood: An International Profile. Social Forces, 94(2), 801–832. https://doi.org/10.1093/sf/sov066

Pool prepared data into one analysis file called "transitions.dta"

*/

run init

* Start with GGS
use ${prepared}/prepared_ggs, clear
* add consecutively ess, deas, nsfh data
append using ${prepared}/prepared_ess
append using ${prepared}/prepared_deas
append using ${prepared}/prepared_nsfh

tab acountry if sampleSelect3==1 & _d==1

recode c (1=1 "Austria") /// 
		 (2=2 "Belgium") /// 
		 (3=3 "Bulgaria") ///
		 (4=4 "Switzerland") /// 
		 (5=5 "Cyprus") ///
		 (6=6 "Germany (TOTAL GGS)") /// 
		 (7=7 "Denmark") ///
		 (8=8 "Estonia") /// 
		 (9=9 "Spain") /// 
		 (10=10 "Finland") /// 
		 (11=11 "France") ///
		 (12=12 "Great Britain") ///
		 (13=13 "Hungary") ///
		 (14=14 "Ireland") ///
		 (15=15 "Netherlands") ///
		 (16=16 "Norway") ///
		 (17=17 "Poland") ///
		 (18=18 "Portugal") ///
		 (19=19 "Russia") ///
		 (20=20 "Sweden") ///
		 (21=21 "Slovenia") ///
		 (22=22 "Slovakia") ///
		 (23=23 "Ukraine") ///
		 (35=28 "Latvia") ///
		 (36=25 "Romania"), gen(country) lab(c)

replace country = 3 if acountry==11
replace country = 19 if acountry==12
replace country = 6 if acountry==14
replace country = 11 if acountry==15
replace country = 13 if acountry==16
replace country = 15 if acountry==18
replace country = 8 if acountry==22

replace country = 26 if acountry==25
replace country = 25 if acountry==19
replace country = 24 if acountry==17
replace country = 27 if acountry==13

replace country = 2 if acountry == 23 
replace country = 16 if acountry == 20

replace country = 29 if usa==1

* code East/West-Germany
replace country = 30 if DEAS == 1 & part == 2
replace country = 31 if DEAS == 1 & part == 1
drop if DEAS == 1 & part == .
drop part


lab def c 24 "Italy" 25 "Romania" 26 "Lithuania" 27 "Georgia" 28 "Latvia" 29 "USA" ///
		  30 "West Germany" 31 "East Germany", modify

// prioritize GGS countries
by country, sort: egen maxESS = max(ESS)
by country, sort: egen maxGGS = max(GGS)
drop if ESS==1 & maxGGS==1


rename _t t 
rename _d d 
rename _t0 t0
rename _st st


gen weight = aweight
replace weight = dweight if dweight < .
// di as err "ACHTUNG: Gewichte in NSFH auf 1 gesetzt!"
// ! set weights for USA to 1
// replace weight = 1 if country==29

gen 	data = 1 if ESS == 1
replace data = 2 if GGS == 1
replace data = 3 if DEAS == 1
replace data = 4 if usa == 1
lab def data 1 "ESS" 2 "GGS" 3 "DEAS" 4 "NSFH"
lab val data data

* 
replace inty = iy if ESS==1



* drop German data from GGS (replaced by DEAS)
drop if country==6


***************************************
* Data cleaning
***************************************


* 1) * Remove some very inplausible times 
* Age at Grandparenthood < 20
fre t if d==1
replace t = .d if t < 20 & d==1

* age at first job
replace ttfirstjob = .d if ttfirstjob < 12 & firstjob==1
* age at first mar 
replace ttfirstmar = .d if ttfirstmar < 12 & mar==1
* age at first child 
replace ttfchild = .d if ttfchild < 12 & fchild==1
* age at nap  (12+16)
replace ttnap = .d if ttnap < 28 & nap==1
* age at retirement
replace ttret = .d if ttret < 12 & ret==1
* recode to non-negative durations
replace ttmarend = .d if ttmarend<12 & inlist(marend,1,2)


* assert valid grandparent data for estimation sample
* assert that no missing values for t in sampleSelect3 (the estimation sample)
assert !mi(t) if sampleSelect3==1
* assert that no missing values for d in sampleSelect3 (the estimation sample)
assert !mi(d) if sampleSelect3==1

/*
* Correction of birth dates
There is a problem with the age and date of birth in the GGS samples

It can be that: (inty-age) < birthy, but
it cannot be true on logical grounds that: (inty-age) > birthy 

Nevertheless, the latter happens in the GGS samples: 

fre data if birthy > (inty-age)
fre data if birthy > (inty-age) & sampleSelect3==1

* these constellations are possible:
fre data if birthy < (inty-age) & sampleSelect3==1
fre data if birthy == (inty-age) & sampleSelect3==1

To remedy that, we recode the year of birth for those cases to (inty-age)
*/
replace birthy = (inty-age) if GGS==1 & birthy > (inty-age) & inty < . & age < . 

***************************************
* TABLE 1 - Samples, Data Sources, and Descriptive Statistics
***************************************
* prepare 
tempfile org sel1 sel2 sel3 events statistics
* orginal case numbers 
preserve 
	keep country sampleSelect*
	gen org = 1 
	collapse (sum) org, by(country)
	save `org'
restore
* case numbers after selection 1 (age limit)
preserve 
	keep country sampleSelect*
	gen sel1 = 1 
	keep if sampleSelect1==1
	collapse (sum) sel1, by(country)
	save `sel1'
restore
* case numbers after selection 2 (child >= 16)
preserve 
	keep country sampleSelect*
	gen sel2 = 1 
	keep if sampleSelect2==1
	collapse (sum) sel2, by(country)
	save `sel2'
restore
* case numbers after selection 2 (valid grandparenthood data)
preserve 
	keep country sampleSelect*
	gen sel3 = 1 
	keep if sampleSelect3==1
	collapse (sum) sel3, by(country)
	save `sel3'
restore
* number of events after selection 2 (valid grandparenthood data)
preserve 
	keep country sampleSelect* d
	gen events = 1 
	keep if sampleSelect3==1 & d==1
	collapse (sum) events, by(country)
	save `events'
restore

* statistics
preserve 
	keep if sampleSelect3 == 1
	// Normalize weights: divide weights by country means of weights
	bys country: egen _meanweight= mean(weight)
	bys country: gen nweight = weight/_meanweight

	gen ageGPH = t if d==1
	
	gen yearGPH = birthy + ageGPH if d==1 // year when the grandparenthood event took place
	
	gen neverpaid = 1 - everpaid
	gen mAge = . 
	gen mAgeGPH = .
	gen medAgeGPH = .
	gen woman = man==0
	gen gp = d==1
	gen mWoman = .
	gen mGP = .
	gen mNeverpaid = .
	gen mRet = .
	gen minBirthy = birthy
	gen maxBirthy = birthy
	gen medYearGPH = .
	
	gen M_mGPHAGE = .
	gen M_medGPHAGE = .
	gen M_mAge = . 
	gen M_mGP = .
	gen M_mNeverpaid = .
	gen M_mRet = .
	gen F_mGPHAGE = .
	gen F_medGPHAGE = .
	gen F_mAge = . 
	gen F_mGP = .
	gen F_mNeverpaid = .
	gen F_mRet = .
	gen M_n = .
	gen M_e = .
	gen F_n = .
	gen F_e = .

	gen nofc = .
	gen F_nofc = .
	gen M_nofc = .


	foreach num of numlist 1/31 {
		count if country==`num'
		if `r(N)'==0 continue
		di `num'
		sum age [aweight=nweight] if country==`num'
		replace mAge = `r(mean)' if country==`num'
		sum woman [aweight=nweight] if country==`num'
		replace mWoman = `r(mean)' if country==`num'
		sum gp [aweight=nweight] if country==`num'
		replace mGP = `r(mean)' if country==`num'
		sum neverpaid [aweight=nweight] if country==`num'
		replace mNeverpaid = `r(mean)' if country==`num'
		sum ret [aweight=nweight] if country==`num'
		replace mRet = `r(mean)' if country==`num'
		sum nofchildren [aweight=nweight] if country==`num'
		replace nofc = `r(mean)' if country==`num'
		sum ageGPH [aweight=nweight] if country==`num', detail
		replace mAgeGPH = `r(mean)' if country==`num'
		replace medAgeGPH = `r(p50)' if country==`num'
		sum yearGPH [aweight=nweight] if country==`num', detail
		replace medYearGPH = `r(p50)' if country==`num'
		
		* Men 
		sum age [aweight=nweight] if man==1 & country==`num'
		replace M_mAge = `r(mean)' if man==1 & country==`num'
		sum gp [aweight=nweight] if man==1 & country==`num'
		replace M_mGP = `r(mean)' if man==1 & country==`num'
		sum neverpaid [aweight=nweight] if man==1 & country==`num'
		replace M_mNeverpaid = `r(mean)' if man==1 & country==`num'
		sum ret [aweight=nweight] if man==1 & country==`num'
		replace M_mRet = `r(mean)' if man==1 & country==`num'
		
		sum t [aweight=nweight] if man==1 & d==1 & country==`num', detail
		replace M_mGPHAGE = `r(mean)' if man==1 & country==`num'
		replace M_medGPHAGE = `r(p50)' if man==1 & country==`num'

		count if man==1 & country==`num'
		replace M_n = `r(N)' if man==1 & country==`num'
		count if man==1 & d==1 & country==`num'
		replace M_e = `r(N)' if man==1 & country==`num'
		
		sum nofchildren [aweight=nweight] if man==1 & country==`num'
		replace M_nofc = `r(mean)' if man==1 & country==`num'
		
		* Women
		sum age [aweight=nweight] if man==0 & country==`num'
		replace F_mAge = `r(mean)' if man==0 & country==`num'
		sum gp [aweight=nweight] if man==0 & country==`num'
		replace F_mGP = `r(mean)' if man==0 & country==`num'
		sum neverpaid [aweight=nweight] if man==0 & country==`num'
		replace F_mNeverpaid = `r(mean)' if man==0 & country==`num'
		sum ret [aweight=nweight] if man==0 & country==`num'
		replace F_mRet = `r(mean)' if man==0 & country==`num'
		sum t [aweight=nweight] if man==0 & d==1 & country==`num', detail
		replace F_mGPHAGE = `r(mean)' if man==0 & country==`num'
		replace F_medGPHAGE = `r(p50)' if man==0 & country==`num'

		count if man==0 & country==`num'
		replace F_n = `r(N)' if man==0 & country==`num'
		count if man==0 & d==1 & country==`num'
		replace F_e = `r(N)' if man==0 & country==`num'

		sum nofchildren [aweight=nweight] if man==0 & country==`num'
		replace F_nofc = `r(mean)' if man==0 & country==`num'

			
	}
	collapse (max) medYearGPH maxBirthy intymin intymax data mAge mAgeGPH medAgeGPH F_* M_* mWoman mGP mNeverpaid mRet (min) minBirthy (mean) nofc woman d neverpaid ret, by(country)
	lab val data data

	gen field = string(intymin) + "-" + string(intymax)
	replace field = string(intymin) if intymin == intymax
	
	gen cohorts = string(minBirthy, "%9.0f") + "-" + string(maxBirthy, "%9.0f")
	format woman d mWoman mGP mNeverpaid mRet  neverpaid ret F_* M_* %9.4f
	format mAge F_mGPHAGE M_mGPHAGE %9.1f

	save `statistics'
restore

preserve  
	use `org', clear
	merge 1:1 country using `sel1', nogen assert(matched)
	merge 1:1 country using `sel2', nogen assert(matched)
	merge 1:1 country using `sel3', nogen assert(matched)
	merge 1:1 country using `events', nogen assert(matched)
	merge 1:1 country using `statistics', nogen assert(matched)

	format woman d mWoman mGP mNeverpaid mRet  neverpaid ret F_* M_* %9.4f
	format mAge F_mGPHAGE M_mGPHAGE %9.1f
	replace mWoman = 100 * mWoman
	replace mGP = 100* mGP	
	format mGP mWoman nofc %9.1f

	gen cohrange = maxBirthy-minBirthy
	
	isid data sel3 events
	sort data sel3 events

	log using $logdir/table1.smcl, name(table1) replace
	* TABLE 1 - Samples, Data Sources, and Descriptive Statistics
	li country data field org sel1 sel2 sel3 events mAge cohorts mWoman nofc mGP F_mGPHAGE M_mGPHAGE F_medGPHAGE M_medGPHAGE medYearGPH, noobs sepby(data)
	
	keep country data field cohrange org sel1 sel2 sel3 events mAge cohorts mWoman nofc mGP F_mGPHAGE M_mGPHAGE F_medGPHAGE M_medGPHAGE F_mGP M_mGP medYearGPH
	save $prepared/table1, replace
	log close table1 
restore 


/*------------------------------------------------------------------------------
  TABLE 1
------------------------------------------------------------------------------*/
preserve 
use $prepared/table1, clear

export excel  country data field cohrange org sel1 sel2 sel3 events mAge cohorts mWoman nofc mGP F_mGPHAGE M_mGPHAGE medYearGPH ///
					 using ${logdir}/Table_1, firstrow(vari) miss("n.a.") replace locale("en")
					 
restore


***************************************
* Sample selection
***************************************
drop tvtot-supqyr
save ${prepared}/transitions_fulldata, replace

/*
* 1) only cases valid gender and age
* drop if gender is missing
drop if man>=.

* drop if age is missing
drop if age>=.

* 2) select individuals of age ${lowerAgeLimit}  or older but not beyond ${upperAgeLimit}
* Additional Sample selection according to age
keep if age >= ${lowerAgeLimit} 

* Upper bond 
keep if age <=${upperAgeLimit} 

// recode birthy (min/1939 = 1 "<1940") (1940/max=2 "1940+"), gen(cohort)
*/

* 
keep if sampleSelect3==1

// Normalize weights: divide weights by country means of weights
bys country: egen _meanweight= mean(weight)
bys country: gen nweight = weight/_meanweight


* Adapt labels: mark GGS countries by *
foreach num of numlist 1/28 {
	capt assert GGS==1 if country==`num'
	if _rc == 0 {
		local clabel: label (country) `num'
		local clabel "`clabel'*"
		local lab: value label country
		lab def `lab' `num' "`clabel'", modify
	}
}
* Mark US with **
local clabel: label (country) 29
local clabel "`clabel'**"
local lab: value label country
lab def `lab' 29 "`clabel'", modify
* Mark DEAS with +
local clabel: label (country) 30
local clabel "`clabel'+"
local lab: value label country
lab def `lab' 30 "`clabel'", modify
local clabel: label (country) 31
local clabel "`clabel'+"
local lab: value label country
lab def `lab' 31 "`clabel'", modify

// some inplausible values
fre t

stset t [iweight=nweight] , f(d)  

* check
stsum, by(country)

* Keep only analytically relevant variables
keep country man birthy nweight maxESS maxGGS usa t d ttdeath1p death1p  ttdeathboth deathboth ttleavehome leavehome ///
	 ttfchild fchild ttnap nap ttret ret ttfirstmar mar ttmarend marend ttfirstjob firstjob
	 
save ${prepared}/transitions, replace
