/*

Replication files 

Leopold, T., & Skopek, J. (2015). The Demography of Grandparenthood: An International Profile. Social Forces, 94(2), 801–832. https://doi.org/10.1093/sf/sov066

Grandparenthood in context of other life course transitions. 

Table 3 
Figure 2 & 3. 

*/


run init

use ${prepared}/transitions, clear


* First step: Create a data file containing median ages of various life course transitions (life course markers)

tempfile gph ret mar nap fchild job death death1p empty marend

* Transition to grandparenthood
preserve 
	stset t [iweight=nweight], f(d)
	gen mdGPH = .
	gen mdFGPH = .
	gen mdMGPH = .
	
	foreach num of numlist 1/31 {
		count if country==`num'
		if `r(N)'==0 continue
		quiet: stsum if country==`num'
		quiet: replace mdGPH = `r(p50)' if country==`num'
		quiet: stsum if country==`num' & man==1
		quiet: replace mdMGPH = `r(p50)' if country==`num'
		quiet: stsum if country==`num' & man==0
		quiet: replace mdFGPH = `r(p50)' if country==`num'
	}
	bys country: keep if _n==1
	keep country mdGPH mdFGPH mdMGPH 
	save `gph'
restore

* Transition to first parent dead
preserve 
	capt mac drop graph
	stset ttdeath1p [iweight=nweight], f(death1p)
	gen mdDEATH1p = .
	gen mdFDEATH1p = .
	gen mdMDEATH1p = .
	
	foreach num of numlist 1/31 {
		count if country==`num'
		if `r(N)'==0 continue
		capt assert death1p==. if country==`num'
		if _rc==0 continue
		quiet: stsum if country==`num'
		quiet: replace mdDEATH1p = `r(p50)' if country==`num'
		quiet: stsum if country==`num' & man==1
		quiet: replace mdMDEATH1p = `r(p50)' if country==`num'
		quiet: stsum if country==`num' & man==0
		quiet: replace mdFDEATH1p = `r(p50)' if country==`num'
		local country: label (country) `num'
		sts graph if country==`num', name(s`num', replace) title("`country'") nodraw
		global graph "${graph} s`num'"
	}
	graph combine ${graph}, cols(4) name(graph, replace) 
	graph export ${logdir}/DEATH1p.pdf, name(graph) replace
	graph drop graph
	bys country: keep if _n==1
	keep country mdDEATH1p mdFDEATH1p mdMDEATH1p
	save `death1p'
restore


* Transition to parentlessness
preserve
	capt mac drop graph
	stset ttdeathboth [iweight=nweight], f(deathboth)
	gen mdDEATHB = .
	gen mdFDEATHB = .
	gen mdMDEATHB = .
	capt mac drop graph
	foreach num of numlist 1/31 {
		count if country==`num'
		if `r(N)'==0 continue
		capt assert deathboth==. if country==`num'
		if _rc==0 continue
		quiet: stsum if country==`num'
		quiet: replace mdDEATHB = `r(p50)' if country==`num'
		quiet: stsum if country==`num' & man==1
		quiet: replace mdMDEATHB = `r(p50)' if country==`num'
		quiet: stsum if country==`num' & man==0
		quiet: replace mdFDEATHB = `r(p50)' if country==`num'
		local country: label (country) `num'
		sts graph if country==`num', name(s`num', replace) title("`country'") nodraw
		global graph "${graph} s`num'"
	}
	graph combine ${graph}, cols(4) name(graph, replace) 
	graph export ${logdir}/DEATHB.pdf, name(graph) replace
	graph drop graph
	
	
	
	bys country: keep if _n==1
	keep country mdDEATHB mdFDEATHB mdMDEATHB 
	save `death'
restore

* Transition to empty nest
preserve 
	stset ttleavehome [iweight=nweight], f(leavehome)
	gen mdEMPTY = .
	gen mdFEMPTY = .
	gen mdMEMPTY = .
	capt mac drop graph
	foreach num of numlist 1/31 {
		count if country==`num'
		if `r(N)'==0 continue
		capt assert leavehome==. if country==`num'
		if _rc==0 continue
		quiet: stsum if country==`num'
		quiet: replace mdEMPTY = `r(p50)' if country==`num'
		quiet: stsum if country==`num' & man==1
		quiet: replace mdMEMPTY = `r(p50)' if country==`num'
		quiet: stsum if country==`num' & man==0
		quiet: replace mdFEMPTY = `r(p50)' if country==`num'
		local country: label (country) `num'
		sts graph if country==`num', by(man) name(s`num', replace) title("`country'") nodraw
		global graph "${graph} s`num'"
	}
	graph combine ${graph}, cols(4) name(graph, replace) 
	graph export ${logdir}/EMPTY.pdf, name(graph) replace
	graph drop graph
	
	bys country: keep if _n==1
	keep country mdEMPTY mdMEMPTY mdFEMPTY
	save `empty'
restore

* Transition to parenthood
preserve
	replace ttfchild = .d if ttfchild<0
	stset ttfchild [iweight=nweight], f(fchild==1)
	gen mdFCHILD = . 
	gen mdFFCHILD = .
	gen mdMFCHILD = .
	capt mac drop graph
	foreach num of numlist 1/31 {
		count if country==`num'
		if `r(N)'==0 continue
		quiet: stsum if country==`num'
		quiet: replace mdFCHILD = `r(p50)' if country==`num'
		quiet: stsum if country==`num' & man == 1
		quiet: replace mdMFCHILD = `r(p50)' if country==`num'
		quiet: stsum if country==`num' & man==0
		quiet: replace mdFFCHILD = `r(p50)' if country==`num'
		local country: label (country) `num'
		sts graph if country==`num', by(man) name(s`num', replace) title("`country'") nodraw
		global graph "${graph} s`num'"
	}
	graph combine ${graph}, cols(4) name(graph, replace) 
	graph export ${logdir}/FCHILD.pdf, name(graph) replace
	graph drop graph
	bys country: keep if _n==1
	keep country mdFCHILD mdMFCHILD mdFFCHILD 
	save `fchild'
restore

* Transition to nonactive parenthood
preserve
	replace ttnap = .d if ttnap<0
	stset ttnap [iweight=nweight], f(nap==1)
	gen mdNAP = . 
	gen mdFNAP = .
	gen mdMNAP = .
	capt mac drop graph
	
	foreach num of numlist 1/31 {
		count if country==`num'
		if `r(N)'==0 continue
		quiet: stsum if country==`num'
		quiet: replace mdNAP = `r(p50)' if country==`num'
		quiet: stsum if country==`num' & man == 1
		quiet: replace mdMNAP = `r(p50)' if country==`num'
		quiet: stsum if country==`num' & man == 0
		quiet: replace mdFNAP = `r(p50)' if country==`num'
		local country: label (country) `num'
		sts graph if country==`num', by(man) name(s`num', replace) title("`country'") nodraw
		global graph "${graph} s`num'"
	}
	graph combine ${graph}, cols(4) name(graph, replace) 
	graph export ${logdir}/NAP.pdf, name(graph) replace
	graph drop graph
	bys country: keep if _n==1
	keep country mdNAP mdFNAP mdMNAP 
	save `nap'
restore 


* Transition to retirement (note: risk group ever paid job people!)
preserve
	replace ttret = .d if ttret<0
	stset ttret [iweight=nweight], f(ret)
	gen mdRET = . 
	gen mdFRET = .
	gen mdMRET = .
	capt mac drop graph
	foreach num of numlist 1/31 {
		count if country==`num'
		if `r(N)'==0 continue
		quiet: capt stsum if country==`num'
		if _rc==0 {
			quiet: replace mdRET = `r(p50)' if country==`num'
		}
		quiet: capt stsum if country==`num' & man == 1
		if _rc==0 {
			quiet: replace mdMRET = `r(p50)' if country==`num'
		}
		quiet: capt stsum if country==`num' & man==0
		if _rc==0 {
			quiet: replace mdFRET = `r(p50)' if country==`num'
		}
		local country: label (country) `num'
		sts graph if country==`num', by(man) name(s`num', replace) title("`country'") nodraw
		log using ${logdir}/SF_retirement_`num', smcl replace
		sts list if country==`num', by(man)
		log close
		global graph "${graph} s`num'"
	}
	graph combine ${graph}, cols(4) name(graph, replace) 
	graph export ${logdir}/ret.pdf, name(graph) replace
	graph drop graph
	bys country: keep if _n==1
	keep country mdRET mdFRET mdMRET 
	save `ret'
restore


* Transition to first marriage
preserve
	replace ttfirstmar = .d if ttfirstmar<0
	stset ttfirstmar [iweight=nweight], f(mar==1)
	gen mdFMAR = . 
	gen mdFFMAR = .
	gen mdMFMAR = .

	
	foreach num of numlist 1/31 {
		count if country==`num'
		if `r(N)'==0 continue
		quiet: capt stsum if country==`num'
		if _rc==0 {
			quiet: replace mdFMAR = `r(p50)' if country==`num'
		}
		quiet: capt stsum if country==`num' & man == 1
		if _rc==0 {
			quiet: replace mdMFMAR = `r(p50)' if country==`num'
		}
		quiet: capt stsum if country==`num' & man == 0
		if _rc==0 {
			quiet: replace mdFFMAR = `r(p50)' if country==`num'
		}
	}
	bys country: keep if _n==1
	keep country mdFMAR mdFFMAR mdMFMAR 
	save `mar'
restore

* Transition to end of first marriage
preserve
	// Data error in Germany: no duration data on death events of partners! 
	// hence, exclude from the analysis
	replace marend = . if country==6
	replace ttmarend = . if country==6
	
	gen dissolution = inlist(marend,1,2) if marend < .
	stset ttmarend [iweight=nweight], f(dissolution==1)
	gen mdMAREND = . 
	gen mdFMAREND = .
	gen mdMMAREND = .

	
	foreach num of numlist 1/31 {
		count if country==`num'
		if `r(N)'==0 continue
		quiet: capt stsum if country==`num'
		if _rc==0 {
			quiet: replace mdMAREND = `r(p50)' if country==`num'
		}
		quiet: capt stsum if country==`num' & man == 1
		if _rc==0 {
			quiet: replace mdMMAREND = `r(p50)' if country==`num'
		}
		quiet: capt stsum if country==`num' & man == 0
		if _rc==0 {
			quiet: replace mdFMAREND = `r(p50)' if country==`num'
		}
	}
	bys country: keep if _n==1
	keep country mdMAREND mdFMAREND mdMMAREND 
	save `marend'
restore

* Transition to first job
preserve
	replace ttfirstjob = .d if ttfirstjob<0
	stset ttfirstjob [iweight=nweight], f(firstjob)
	gen mdFJOB = . 
	gen mdFFJOB = . 
	gen mdMFJOB = . 
	
	foreach num of numlist 1/31 {
		count if country==`num'
		if `r(N)'==0 continue
		quiet: capt stsum if country==`num'
		if _rc==0 {
			quiet: replace mdFJOB = `r(p50)' if country==`num'
		}
		quiet: capt stsum if country==`num' & man == 1
		if _rc==0 {
			quiet: replace mdMFJOB = `r(p50)' if country==`num'
		}
		quiet: capt stsum if country==`num' & man == 0
		if _rc==0 {
			quiet: replace mdFFJOB = `r(p50)' if country==`num'
		}
	}
	bys country: keep if _n==1
	keep country mdFJOB mdFFJOB mdMFJOB 
	save `job'
restore

* Cumulate Median ages
use `gph', clear
merge 1:1 country using `fchild', nogen
merge 1:1 country using `mar', nogen
merge 1:1 country using `ret', nogen
merge 1:1 country using `nap', nogen
merge 1:1 country using `job', nogen
merge 1:1 country using `death', nogen
merge 1:1 country using `death1p', nogen
merge 1:1 country using `empty', nogen
merge 1:1 country using `marend', nogen

save ${prepared}/lifecourse_markers, replace



* Merge cross-national data on life-expectance at 60 
use ${prepared}/lifecourse_markers, clear

merge 1:1 country using "${lifeexpect}", assert(matched) keepusing(LE60_2 LE60_3)

gen LEwomen = 60 + LE60_2
gen LEmen = 60 + LE60_3

* Sort data
gsort -mdFGPH -mdMGPH +country

* create a new country code according to sorting
capt drop csort
capt lab drop csort
gen csort = _n
foreach num of numlist 1/31 {
	local value = country[`num']
	local c: label (country) `value'
	lab def csort `num' "`c'", modify
}
lab val csort csort


/*------------------------------------------------------------------------------
  TABLE 3
  (note: the data for the table is produced in a stata log file)  
------------------------------------------------------------------------------*/


log using ${logdir}/Table_3, smcl replace

* WOMEN 
* Mean and SD
tabstat mdFFCHILD	///
		mdFNAP		///
		mdFGPH		///
		mdFRET		///
		LEwomen ///
		, stats(mean sd) column(stats) f(%9.1f)

* Gini and RMD
* Note: requires user-written command "ainequal" (type "findit ainequal" OR "ssc install ainequal")
ainequal mdFFCHILD	///
		mdFNAP 	mdFGPH mdFRET LEwomen	, f(%9.3f)
ainequal LEwomen	, f(%9.3f)

* MEN
* Mean and SD
tabstat mdMFCHILD	///
		mdMNAP		///
		mdMGPH		///
		mdMRET		///
		LEmen ///
		, stats(mean sd) column(stats) f(%9.1f)
* Gini and RMD
ainequal mdMFCHILD	///
		mdMNAP	mdMGPH mdMRET LEmen	, f(%9.3f)
		
log close



// group countries
recode country (1 2 4 9 11 12 15 17 18 30  = 1  "Western Europe") /// 
			   (7 10 16 20 = 2 "Scandinavian") ///
			   (29 = 3 "USA") ///
			   (3 8 13 19 21 23 25 26 27 28 31 = 4 "Post-Socialist"), gen(cgroup)
tabstat mdFFCHILD	///
		mdFNAP		///
		mdFGPH		///
		mdFRET		///
		LEwomen ///
		, by(cgroup) stats(N mean sd) f(%9.2f)
gen OwnGenProp = mdMFCHILD/mdGPH
tabstat OwnGenProp, by(cgroup) stats( N mean min max) f(%9.3f)

		



/*------------------------------------------------------------------------------
  Figure 2 (women -> grandmotherhood)
------------------------------------------------------------------------------*/

/*
 Note: There are some small differences between sexes in the estimation of death of their parents.
 However, we would not expect such differences on substantive grounds (sex should not be affect the timing of parents death).
 Deviations might be a result of sample errors and potentially some differential selectivities in the samples of men and women. Hence, for death of parents, we use the estimation for the total population for both sexes (mdDEATH1p and mdDEATHB). This eases interpretation.  
*/

* Including life-exectancy at age 60
twoway (scatter csort mdFFCHILD , mlabel(mdFFCHILD) msymbol(T) mlabcolor(black) mlabposition(12) mlabsize(*.4) mlabgap(*.5) mlwidth(thin) msize(*1) mlcolor(green) mcolor(midgreen)) || ///
	   (scatter csort mdFNAP , mlabel(mdFNAP) msymbol(Oh) mlabcolor(black) mlabposition(12) mlabgap(*.5) mlabsize(*.4) mlwidth(thin) msize(*1) mcolor(midgreen)) || ///
	   (scatter csort mdFGPH , mlabel(mdFGPH) msymbol(D) mlabcolor(black) mlabposition(12) mlabgap(*.5) mlabsize(*.4)  mlwidth(thin) msize(*1) mlcolor(cranberry) mcolor(cranberry*.5)) || ///
	   (scatter csort mdFEMPTY , mlabel(mdFEMPTY) msymbol(th) mlabcolor(black) mlabposition(12) mlabgap(*.5) mlabsize(*.4) mlwidth(thin) msize(*1) mcolor(midgreen)) || ///
	   (scatter csort mdFRET , mlabel(mdFRET) msymbol(Sh) mlabcolor(black) mlabposition(12) mlabgap(*.5) mlabsize(*.4) mlwidth(thin) msize(*1) mcolor(sienna)) || ///
	   (scatter csort mdDEATH1p, mlabel(mdDEATH1p) msymbol(smplus) mlabcolor(black) mlabposition(12) mlabgap(*.5) mlabsize(*.4) mlwidth(thin) msize(*1) mcolor(black)) || ///
	   (scatter csort mdDEATHB , mlabel(mdDEATHB) msymbol(+) mlabcolor(black) mlabposition(12) mlabgap(*.5) mlabsize(*.4) mlwidth(thin) msize(*1) mcolor(black)) || ///
	   (scatter csort LEwomen , mlabel(LEwomen) msymbol(X) mlabcolor(black) mlabposition(12) mlabgap(*.5) mlabsize(*.4) mlwidth(thin) msize(*1) mcolor(gs10)), ///
		legend(lab(1 "Birth of 1st child") lab(2 "End of active motherhood") lab(4 "Empty nest") lab(3 "Grandmotherhood") /// 
			   lab(5 "Retirement/Inactivity") lab(6 "1st parent dead") lab(7 "2nd parent dead") lab(8 "Life expectancy at age 60") region(style(none) ) rows(2) size(tiny)) ///
		graphregion(color(white)) plotregion(style(outline)) ///
		xlabel(20(5)85, labsize(*.5) nogrid ) /// 
		xmtick(20(1)85)  xtitle("Age", size(*.5)) ///  
		ylabel(1(1)26, valuelabels grid glcolor(gs14) glwidth(vthin) angle(360) labsize(*.5)) /// 
		xsize(15.6) ysize(17)  /// scale(.8) ///
		ytitle("") xtitle("Age", size(vsmall)) /// 
		saving("${logdir}/Figure_2.gph", replace) ///
		name(Figure_2, replace)
graph export "${logdir}/Figure_2.pdf", name(Figure_2) replace
graph export "${logdir}/Figure_2.eps", name(Figure_2) replace


* Sorting
gsort -csort
capt drop femaleOrder
gen femaleOrder = _n

* sorting for men
gsort -mdMGPH -mdFGPH +country

capt drop csortM
capt lab drop csortM
gen csortM = _n
foreach num of numlist 1/31 {
	local value = country[`num']
	local order = femaleOrder[`num']
	local c: label (country) `value'
	lab def csortM `num' "`c' (`order')", modify
}
lab val csortM csortM


/*------------------------------------------------------------------------------
  Figure 3 (men -> grandfatherhood)
------------------------------------------------------------------------------*/

* including life expectancy
twoway (scatter csortM mdMFCHILD , mlabel(mdMFCHILD) msymbol(T) mlabcolor(black) mlabposition(12) mlabsize(*.4) mlabgap(*.5) mlwidth(thin) msize(*1) mlcolor(green) mcolor(midgreen)) || ///
	   (scatter csortM mdMNAP , mlabel(mdMNAP) msymbol(Oh) mlabcolor(black) mlabposition(12) mlabgap(*.5) mlabsize(*.4) mlwidth(thin) msize(*1) mcolor(midgreen)) || ///
	   (scatter csortM mdMGPH , mlabel(mdMGPH) msymbol(D) mlabcolor(black) mlabposition(12) mlabgap(*.5) mlabsize(*.4)  mlwidth(thin) msize(*1) mlcolor(blue) mcolor(blue*.6)) || ///
	   (scatter csortM mdMEMPTY , mlabel(mdMEMPTY) msymbol(th) mlabcolor(black) mlabposition(12) mlabgap(*.5) mlabsize(*.4) mlwidth(thin) msize(*1) mcolor(midgreen)) || ///
	   (scatter csortM mdMRET , mlabel(mdMRET) msymbol(Sh) mlabcolor(black) mlabposition(12) mlabgap(*.5) mlabsize(*.4) mlwidth(thin) msize(*1) mcolor(sienna)) || ///
	   (scatter csortM mdDEATH1p, mlabel(mdDEATH1p) msymbol(smplus) mlabcolor(black) mlabposition(12) mlabgap(*.5) mlabsize(*.4) mlwidth(thin) msize(*1) mcolor(black)) || ///
	   (scatter csortM mdDEATHB , mlabel(mdDEATHB) msymbol(+) mlabcolor(black) mlabposition(12) mlabgap(*.5) mlabsize(*.4) mlwidth(thin) msize(*1) mcolor(black)) ||  ///
	   (scatter csortM LEmen , mlabel(LEmen) msymbol(X) mlabcolor(black) mlabposition(12) mlabgap(*.5) mlabsize(*.4) mlwidth(thin) msize(*1) mcolor(gs10)), ///
		legend(lab(1 "Birth of 1st child") lab(2 "End of active fatherhood") lab(4 "Empty nest") lab(3 "Grandfatherhood") /// 
			  lab(5 "Retirement/Inactivity") lab(6 "1st parent dead") lab(7 "2nd parent dead") lab(8 "Life expectancy at age 60") region(style(none) ) rows(2) size(tiny)) ///
		graphregion(color(white)) plotregion(style(outline)) ///
		xlabel(20(5)85, labsize(*.5) nogrid ) /// 
		xmtick(20(1)85)  xtitle("Age", size(*.5)) ///  
		ylabel(1(1)26, valuelabels grid glcolor(gs12) angle(360) glwidth(vthin) labsize(*.5)) /// 
		xsize(15.6) ysize(17) /// scale(.8) ///
		ytitle("") xtitle("Age", size(vsmall)) /// xsize(8.3) ysize(11) /// scale(.8) /// title("Sequencing of Grandparenthood in the Life Course", size(small)) /// note("Risk-set: child of 16 or older at time of interview; for retirement/inactivity additionally ever had paid job;" "weighted calculation expect for Latvia; median age of empty nest not feasible for Georgia;" "empty nest only available for GGS data and filial context only availble for GGS and NSFH data;" "ordering of countries for women in parantheses; Data: ESS data, * GGS data, ** NSFH data", size(tiny)) subtitle("median ages (men)", size(small)) ///
		saving("${logdir}/Figure_3.gph", replace) ///
		name(Figure_3, replace)
graph export "${logdir}/Figure_3.pdf", name(Figure_3) replace
graph export "${logdir}/Figure_3.eps", name(Figure_3) replace




/*------------------------------------------------------------------------------
  Length of the grandparenthood stage
------------------------------------------------------------------------------*/

li country LEmen mdMGPH LEwomen mdFGPH, noobs clean

* Correlation: Life expectancy at age 60 and median age at grandparenthood
* Men
corr LEmen mdMGPH // .79
* Women
corr LEwomen mdFGPH // .72


		

